@@ -72,13 +72,17 @@ hook_command_build_completion (struct t_hook_command *hook_command)
 {
     int i, j, k, length, num_items;
     struct t_weelist *list;
-    char *pos_completion, *pos_double_pipe, *pos_start, *pos_end;
+    char *completion, *pos_completion, *pos_double_pipe, *pos_start, *pos_end;
     char **items;
     const char *last_space, *ptr_template;
 
+    completion = string_replace (hook_command->completion, "\n", " ");
+    if (!completion)
+        return;
+
     /* split templates using "||" as separator */
     hook_command->cplt_num_templates = 1;
-    pos_completion = hook_command->completion;
+    pos_completion = completion;
     while ((pos_double_pipe = strstr (pos_completion, "||")) != NULL)
     {
         hook_command->cplt_num_templates++;
@@ -90,7 +94,7 @@ hook_command_build_completion (struct t_hook_command *hook_command)
     {
         hook_command->cplt_templates[i] = NULL;
     }
-    pos_completion = hook_command->completion;
+    pos_completion = completion;
     i = 0;
     while (pos_completion)
     {
@@ -174,6 +178,7 @@ hook_command_build_completion (struct t_hook_command *hook_command)
         hook_command->cplt_template_args[i] = string_split (
             hook_command->cplt_templates[i],
             " ",
+            NULL,
             WEECHAT_STRING_SPLIT_STRIP_LEFT
             | WEECHAT_STRING_SPLIT_STRIP_RIGHT
             | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -218,6 +223,7 @@ hook_command_build_completion (struct t_hook_command *hook_command)
                         items = string_split (
                             hook_command->cplt_template_args[j][i],
                             "|",
+                            NULL,
                             WEECHAT_STRING_SPLIT_STRIP_LEFT
                             | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                             | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -242,6 +248,8 @@ hook_command_build_completion (struct t_hook_command *hook_command)
         }
         weelist_free (list);
     }
+
+    free (completion);
 }
 
 /*
@@ -349,7 +357,7 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
     if (hook_command_run_exec (buffer, string) == WEECHAT_RC_OK_EAT)
         return HOOK_COMMAND_EXEC_OK;
 
-    argv = string_split (string, " ",
+    argv = string_split (string, " ", NULL,
                          WEECHAT_STRING_SPLIT_STRIP_LEFT
                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -359,7 +367,7 @@ hook_command_exec (struct t_gui_buffer *buffer, int any_plugin,
         string_free_split (argv);
         return HOOK_COMMAND_EXEC_NOT_FOUND;
     }
-    argv_eol = string_split (string, " ",
+    argv_eol = string_split (string, " ", NULL,
                              WEECHAT_STRING_SPLIT_STRIP_LEFT
                              | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                              | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
