@@ -233,7 +233,7 @@ hook_focus_get_data (struct t_hashtable *hashtable_focus1,
         keys = hashtable_get_string (hashtable1, "keys");
         if (keys)
         {
-            list_keys = string_split (keys, ",",
+            list_keys = string_split (keys, ",", NULL,
                                       WEECHAT_STRING_SPLIT_STRIP_LEFT
                                       | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                                       | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
