@@ -78,7 +78,13 @@ hook_line (struct t_weechat_plugin *plugin, const char *buffer_type,
         new_hook_line->buffer_type = gui_buffer_search_type (buffer_type);
     new_hook_line->buffers = string_split (
         (buffer_name && buffer_name[0]) ? buffer_name : "*",
-        ",", 0, 0, &new_hook_line->num_buffers);
+        ",",
+        NULL,
+        WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+        0,
+        &new_hook_line->num_buffers);
     new_hook_line->tags_array = string_split_tags (tags,
                                                    &new_hook_line->tags_count);
 
@@ -113,9 +119,9 @@ hook_line_exec (struct t_gui_line *line)
         if (!ptr_hook->deleted && !ptr_hook->running
             && ((HOOK_LINE(ptr_hook, buffer_type) == -1)
                 || ((int)(line->data->buffer->type) == (HOOK_LINE(ptr_hook, buffer_type))))
-            && gui_buffer_match_list_split (line->data->buffer,
-                                            HOOK_LINE(ptr_hook, num_buffers),
-                                            HOOK_LINE(ptr_hook, buffers))
+            && string_match_list (line->data->buffer->full_name,
+                                  (const char **)HOOK_LINE(ptr_hook, buffers),
+                                  0)
             && (!HOOK_LINE(ptr_hook, tags_array)
                 || gui_line_match_tags (line->data,
                                         HOOK_LINE(ptr_hook, tags_count),
