@@ -1,7 +1,7 @@
 /*
  * wee-debug.c - debug functions
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -581,8 +581,12 @@ debug_directories ()
 
     gui_chat_printf (NULL, "");
     gui_chat_printf (NULL, _("Directories:"));
-    gui_chat_printf (NULL, "  home: %s (%s: %s)",
-                     weechat_home, _("default"), WEECHAT_HOME);
+    gui_chat_printf (NULL, "  home: %s%s%s",
+                     weechat_home,
+                     (weechat_home_temp) ? " " : "",
+                     (weechat_home_temp) ? _("(TEMPORARY, deleted on exit)") : "");
+    gui_chat_printf (NULL, _("        (default: %s)"),
+                     WEECHAT_HOME);
     gui_chat_printf (NULL, "  lib: %s", WEECHAT_LIBDIR);
     gui_chat_printf (NULL, "  lib (extra): %s",
                      (extra_libdir && extra_libdir[0]) ? extra_libdir : "-");
