@@ -23,10 +23,16 @@
 struct t_gui_buffer;
 struct t_weechat_plugin;
 
+extern char **input_commands_allowed;
+
 extern int input_exec_command (struct t_gui_buffer *buffer,
                                int any_plugin,
                                struct t_weechat_plugin *plugin,
-                               const char *string);
-extern int input_data (struct t_gui_buffer *buffer, const char *data);
+                               const char *string,
+                               const char *commands_allowed);
+extern int input_data (struct t_gui_buffer *buffer, const char *data,
+                       const char *commands_allowed);
+extern int input_data_delayed (struct t_gui_buffer *buffer, const char *data,
+                               const char *commands_allowed, long delay);
 
 #endif /* WEECHAT_INPUT_H */
