@@ -1,7 +1,7 @@
 /*
  * wee-upgrade-file.c - save/restore data for upgrading WeeChat
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -291,7 +291,11 @@ upgrade_file_write_object (struct t_upgrade_file *upgrade_file, int object_id,
         fields = infolist_fields (infolist);
         if (fields)
         {
-            argv = string_split (fields, ",", 0, 0, &argc);
+            argv = string_split (fields, ",", NULL,
+                                 WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                 | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                 | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                 0, &argc);
             if (argv && (argc > 0))
             {
                 for (i = 0; i < argc; i++)
