@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2012-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +14,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_URL_H
-#define WEECHAT_URL_H 1
+#define WEECHAT_URL_H
+
+#include <stdio.h>
 
 struct t_hashtable;
 struct t_infolist;
@@ -29,6 +31,7 @@ enum t_url_type
     URL_TYPE_LONG,
     URL_TYPE_LONGLONG,
     URL_TYPE_MASK,
+    URL_TYPE_LIST,
 };
 
 struct t_url_constant
