@@ -1,7 +1,7 @@
 /*
  * wee-version.c - functions for WeeChat version
  *
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -134,3 +134,16 @@ version_get_compilation_time ()
 {
     return __TIME__;
 }
+
+/*
+ * Returns date/time of WeeChat compilation.
+ *
+ * Example:
+ *   Dec 16 2012 18:10:22
+ */
+
+const char *
+version_get_compilation_date_time ()
+{
+    return __DATE__ " " __TIME__;
+}
