@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  * Copyright (C) 2006 Emmanuel Bouthenot <kolter@openics.org>
  *
  * This file is part of WeeChat, the extensible chat client.
@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_H
@@ -53,7 +53,7 @@
 #endif /* !defined(_) */
 
 
-#define WEECHAT_COPYRIGHT_DATE   "(C) 2003-2018"
+#define WEECHAT_COPYRIGHT_DATE   "(C) 2003-2019"
 #define WEECHAT_WEBSITE          "https://weechat.org/"
 #define WEECHAT_WEBSITE_DOWNLOAD "https://weechat.org/download"
 
@@ -74,7 +74,7 @@
     "GNU General Public License for more details.\n" \
     "\n" \
     "You should have received a copy of the GNU General Public License\n" \
-    "along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.\n\n"
+    "along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.\n\n"
 
 /* directory separator, depending on OS */
 #ifdef _WIN32
@@ -96,6 +96,8 @@
 /* name of environment variable with an extra lib dir */
 #define WEECHAT_EXTRA_LIBDIR "WEECHAT_EXTRA_LIBDIR"
 
+struct t_weelist;
+
 /* global variables and functions */
 extern int weechat_headless;
 extern int weechat_debug_core;
@@ -108,11 +110,12 @@ extern int weechat_upgrade_count;
 extern volatile sig_atomic_t weechat_quit;
 extern volatile sig_atomic_t weechat_quit_signal;
 extern char *weechat_home;
+extern int weechat_home_temp;
 extern char *weechat_local_charset;
 extern int weechat_plugin_no_dlclose;
 extern int weechat_no_gnutls;
 extern int weechat_no_gcrypt;
-extern char *weechat_startup_commands;
+extern struct t_weelist *weechat_startup_commands;
 
 extern void weechat_term_check ();
 extern void weechat_shutdown (int return_code, int crash);
