@@ -246,6 +246,7 @@ extern char *gui_buffer_properties_set[];
 /* buffer functions */
 
 extern int gui_buffer_search_type (const char *type);
+extern int gui_buffer_search_notify (const char *notify);
 extern const char *gui_buffer_get_plugin_name (struct t_gui_buffer *buffer);
 extern const char *gui_buffer_get_short_name (struct t_gui_buffer *buffer);
 extern void gui_buffer_build_full_name (struct t_gui_buffer *buffer);
@@ -270,8 +271,6 @@ extern void gui_buffer_user_set_callbacks ();
 extern int gui_buffer_valid (struct t_gui_buffer *buffer);
 extern char *gui_buffer_string_replace_local_var (struct t_gui_buffer *buffer,
                                                   const char *string);
-extern int gui_buffer_match_list_split (struct t_gui_buffer *buffer,
-                                        int num_buffers, char **buffers);
 extern int gui_buffer_match_list (struct t_gui_buffer *buffer,
                                   const char *string);
 extern void gui_buffer_set_plugin_for_upgrade (char *name,
