@@ -1159,7 +1159,7 @@ gui_key_focus_command (const char *key, int context,
                                                  command,
                                                  ptr_buffer->full_name);
                             }
-                            (void) input_data (ptr_buffer, command);
+                            (void) input_data (ptr_buffer, command, NULL);
                             free (command);
                         }
                     }
@@ -1388,7 +1388,7 @@ gui_key_pressed (const char *key_str)
                     for (i = 0; commands[i]; i++)
                     {
                         (void) input_data (gui_current_window->buffer,
-                                           commands[i]);
+                                           commands[i], NULL);
                     }
                     string_free_split (commands);
                 }
