@@ -33,8 +33,6 @@ struct t_config_section *alias_config_section_completion = NULL;
 
 char *alias_default[][3] =
 { { "AAWAY",   "allserv /away",        NULL            },
-  { "AME",     "allchan /me",          NULL            },
-  { "AMSG",    "allchan /msg *",       NULL            },
   { "ANICK",   "allserv /nick",        NULL            },
   { "BEEP",    "print -beep",          NULL            },
   { "BYE",     "quit",                 NULL            },
@@ -62,9 +60,10 @@ char *alias_default[][3] =
   { "UMODE",   "mode $nick",           NULL            },
   { "V",       "command core version", NULL            },
   { "W",       "who",                  NULL            },
-  { "WC",      "window merge",         NULL            },
+  { "WC",      "window close",         NULL            },
   { "WI",      "whois",                NULL            },
   { "WII",     "whois $1 $1",          NULL            },
+  { "WM",      "window merge",         NULL            },
   { "WW",      "whowas",               NULL            },
   { NULL,      NULL,                   NULL            },
 };
