@@ -190,7 +190,7 @@ alias_replace_args (const char *alias_args, const char *user_args)
     const char *start, *pos;
     int n, m, argc, length_res, args_count, offset;
 
-    argv = weechat_string_split (user_args, " ",
+    argv = weechat_string_split (user_args, " ", NULL,
                                  WEECHAT_STRING_SPLIT_STRIP_LEFT
                                  | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                                  | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
