@@ -63,7 +63,13 @@ exec_config_change_command_default_options (const void *pointer, void *data,
 
     exec_config_cmd_options = weechat_string_split (
         weechat_config_string (exec_config_command_default_options),
-        " ", 0, 0, &exec_config_cmd_num_options);
+        " ",
+        NULL,
+        WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+        0,
+        &exec_config_cmd_num_options);
 }
 
 /*
@@ -136,8 +142,9 @@ exec_config_init ()
         "shell", "string",
         N_("shell to use with command \"/exec -sh\"; it can be just the name "
            "of shell if it is in PATH (for example \"bash\") or the absolute "
-           "path to the shell (for example \"/bin/bash\")"),
-        NULL, 0, 0, "sh", NULL, 0,
+           "path to the shell (for example \"/bin/bash\"); if value is empty, "
+           "\"sh\" is used (note: content is evaluated, see /help eval)"),
+        NULL, 0, 0, "${env:SHELL}", NULL, 0,
         NULL, NULL, NULL,
         NULL, NULL, NULL,
         NULL, NULL, NULL);
