@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_FIFO_H
-#define WEECHAT_FIFO_H 1
+#ifndef WEECHAT_PLUGIN_FIFO_H
+#define WEECHAT_PLUGIN_FIFO_H
 
 #define weechat_plugin weechat_fifo_plugin
 #define FIFO_PLUGIN_NAME "fifo"
@@ -31,4 +31,4 @@ extern char *fifo_filename;
 extern void fifo_create ();
 extern void fifo_remove ();
 
-#endif /* WEECHAT_FIFO_H */
+#endif /* WEECHAT_PLUGIN_FIFO_H */
