@@ -469,7 +469,7 @@ fset_command_run_set_cb (const void *pointer, void *data,
 
     rc = WEECHAT_RC_OK;
 
-    argv = weechat_string_split (command, " ",
+    argv = weechat_string_split (command, " ", NULL,
                                  WEECHAT_STRING_SPLIT_STRIP_LEFT
                                  | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                                  | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -646,6 +646,10 @@ fset_command_init ()
            "value\n"
            "               d==xxx  show only changed options with exact value "
            "\"xxx\"\n"
+           "               h=xxx   show only options with \"xxx\" in "
+           "description (translated)\n"
+           "               he=xxx  show only options with \"xxx\" in "
+           "description (in English)\n"
            "               =xxx    show only options with \"xxx\" in value\n"
            "               ==xxx   show only options with exact value \"xxx\"\n"
            "               c:xxx   show only options matching the evaluated "
