@@ -153,7 +153,13 @@ fset_config_change_sort_cb (const void *pointer, void *data,
 
     fset_config_sort_fields = weechat_string_split (
         weechat_config_string (fset_config_look_sort),
-        ",", 0, 0, &fset_config_sort_fields_count);
+        ",",
+        NULL,
+        WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+        0,
+        &fset_config_sort_fields_count);
 
     if (fset_buffer)
     {
@@ -476,7 +482,7 @@ fset_config_init ()
         fset_config_file, ptr_section,
         "option2", "string",
         N_("second format of each line with an option which is not marked "
-           "not the selected one "
+           "nor the selected one "
            "(note: content is evaluated, see /help fset); "
            "an empty string uses the default format "
            "(\"${marked} ${name}  ${type}  ${value2}\"), which is without "
