@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_IRC_CTCP_H
-#define WEECHAT_IRC_CTCP_H 1
+#ifndef WEECHAT_PLUGIN_IRC_CTCP_H
+#define WEECHAT_PLUGIN_IRC_CTCP_H
 
 #include <time.h>
 
@@ -44,4 +44,4 @@ extern void irc_ctcp_recv (struct t_irc_server *server, time_t date,
                            const char *remote_nick, char *arguments,
                            char *message);
 
-#endif /* WEECHAT_IRC_CTCP_H */
+#endif /* WEECHAT_PLUGIN_IRC_CTCP_H */
