@@ -336,7 +336,7 @@ struct t_hashtable *
 irc_message_parse_to_hashtable (struct t_irc_server *server,
                                 const char *message)
 {
-    char *tags,*message_without_tags, *nick, *host, *command, *channel;
+    char *tags, *message_without_tags, *nick, *host, *command, *channel;
     char *arguments, *text, str_pos[32];
     char empty_str[1] = { '\0' };
     int pos_command, pos_arguments, pos_channel, pos_text;
@@ -495,6 +495,9 @@ irc_message_get_address_from_host (const char *host)
     char host2[256], *pos_space, *pos;
     const char *ptr_host;
 
+    if (!host)
+        return NULL;
+
     address[0] = '\0';
     if (host)
     {
@@ -655,7 +658,7 @@ irc_message_split_string (struct t_hashtable *hashtable,
                           const char *arguments,
                           const char *suffix,
                           const char delimiter,
-                          int max_length_host,
+                          int max_length_nick_user_host,
                           int max_length)
 {
     const char *pos, *pos_max, *pos_next, *pos_last_delim;
@@ -663,8 +666,8 @@ irc_message_split_string (struct t_hashtable *hashtable,
     int number;
 
     max_length -= 2;  /* by default: 512 - 2 = 510 bytes */
-    if (max_length_host >= 0)
-        max_length -= max_length_host;
+    if (max_length_nick_user_host >= 0)
+        max_length -= max_length_nick_user_host;
     else
         max_length -= (host) ? strlen (host) + 1 : 0;
     max_length -= strlen (command) + 1;
@@ -779,18 +782,30 @@ irc_message_split_join (struct t_hashtable *hashtable,
         str = weechat_strndup (arguments, pos - arguments);
         if (!str)
             return 0;
-        channels = weechat_string_split (str, ",", 0, 0, &channels_count);
+        channels = weechat_string_split (str, ",", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                         0, &channels_count);
         free (str);
         while (pos[0] == ' ')
         {
             pos++;
         }
         if (pos[0])
-            keys = weechat_string_split (pos, ",", 0, 0, &keys_count);
+            keys = weechat_string_split (pos, ",", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                         0, &keys_count);
     }
     else
     {
-        channels = weechat_string_split (arguments, ",", 0, 0, &channels_count);
+        channels = weechat_string_split (arguments, ",", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                         0, &channels_count);
     }
 
     snprintf (msg_to_send, sizeof (msg_to_send), "%s%sJOIN",
@@ -871,7 +886,7 @@ int
 irc_message_split_privmsg_notice (struct t_hashtable *hashtable,
                                   char *tags, char *host, char *command,
                                   char *target, char *arguments,
-                                  int max_length_host,
+                                  int max_length_nick_user_host,
                                   int max_length)
 {
     char prefix[4096], suffix[2], *pos, saved_char;
@@ -911,7 +926,7 @@ irc_message_split_privmsg_notice (struct t_hashtable *hashtable,
 
     rc = irc_message_split_string (hashtable, tags, host, command, target,
                                    prefix, arguments, suffix,
-                                   ' ', max_length_host, max_length);
+                                   ' ', max_length_nick_user_host, max_length);
 
     return rc;
 }
@@ -987,8 +1002,8 @@ irc_message_split (struct t_irc_server *server, const char *message)
     struct t_hashtable *hashtable;
     char **argv, **argv_eol, *tags, *host, *command, *arguments, target[4096];
     char *pos, monitor_action[3];
-    int split_ok, argc, index_args, max_length_nick, max_length_host;
-    int split_msg_max_length;
+    int split_ok, argc, index_args, max_length_nick, max_length_user;
+    int max_length_host, max_length_nick_user_host, split_msg_max_length;
 
     split_ok = 0;
     tags = NULL;
@@ -1042,8 +1057,16 @@ irc_message_split (struct t_irc_server *server, const char *message)
         }
     }
 
-    argv = weechat_string_split (message, " ", 0, 0, &argc);
-    argv_eol = weechat_string_split (message, " ", 2, 0, NULL);
+    argv = weechat_string_split (message, " ", NULL,
+                                 WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                 | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                 | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                 0, &argc);
+    argv_eol = weechat_string_split (message, " ", NULL,
+                                     WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                     | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
+                                     | WEECHAT_STRING_SPLIT_KEEP_EOL,
+                                     0, NULL);
 
     if (argc < 2)
         goto end;
@@ -1066,11 +1089,18 @@ irc_message_split (struct t_irc_server *server, const char *message)
 
     max_length_nick = (server && (server->nick_max_length > 0)) ?
         server->nick_max_length : 16;
-    max_length_host = 1 + /* ":"  */
-        max_length_nick + /* nick */
-        1 +               /* "!"  */
-        63 +              /* host */
-        1;                /* " "  */
+    max_length_user = (server && (server->user_max_length > 0)) ?
+        server->user_max_length : 10;
+    max_length_host = (server && (server->host_max_length > 0)) ?
+        server->host_max_length : 63;
+
+    max_length_nick_user_host = 1 +  /* ":"  */
+        max_length_nick +            /* nick */
+        1 +                          /* "!"  */
+        max_length_user +            /* user */
+        1 +                          /* @    */
+        max_length_host +            /* host */
+        1;                           /* " "  */
 
     if ((weechat_strcasecmp (command, "ison") == 0)
         || (weechat_strcasecmp (command, "wallops") == 0))
@@ -1083,7 +1113,7 @@ irc_message_split (struct t_irc_server *server, const char *message)
             hashtable, tags, host, command, NULL, ":",
             (argv_eol[index_args][0] == ':') ?
             argv_eol[index_args] + 1 : argv_eol[index_args],
-            NULL, ' ', max_length_host, split_msg_max_length);
+            NULL, ' ', max_length_nick_user_host, split_msg_max_length);
     }
     else if (weechat_strcasecmp (command, "monitor") == 0)
     {
@@ -1098,7 +1128,7 @@ irc_message_split (struct t_irc_server *server, const char *message)
                       "%c ", argv_eol[index_args][0]);
             split_ok = irc_message_split_string (
                 hashtable, tags, host, command, NULL, monitor_action,
-                argv_eol[index_args] + 2, NULL, ',', max_length_host,
+                argv_eol[index_args] + 2, NULL, ',', max_length_nick_user_host,
                 split_msg_max_length);
         }
         else
@@ -1107,7 +1137,7 @@ irc_message_split (struct t_irc_server *server, const char *message)
                 hashtable, tags, host, command, NULL, ":",
                 (argv_eol[index_args][0] == ':') ?
                 argv_eol[index_args] + 1 : argv_eol[index_args],
-                NULL, ',', max_length_host, split_msg_max_length);
+                NULL, ',', max_length_nick_user_host, split_msg_max_length);
         }
     }
     else if (weechat_strcasecmp (command, "join") == 0)
@@ -1133,7 +1163,7 @@ irc_message_split (struct t_irc_server *server, const char *message)
                 hashtable, tags, host, command, argv[index_args],
                 (argv_eol[index_args + 1][0] == ':') ?
                 argv_eol[index_args + 1] + 1 : argv_eol[index_args + 1],
-                max_length_host, split_msg_max_length);
+                max_length_nick_user_host, split_msg_max_length);
         }
     }
     else if (weechat_strcasecmp (command, "005") == 0)
@@ -1187,7 +1217,11 @@ end:
     if (!split_ok
         || (weechat_hashtable_get_integer (hashtable, "items_count") == 0))
     {
-        irc_message_split_add (hashtable, 1, tags, message, arguments);
+        irc_message_split_add (hashtable,
+                               (message) ? 1 : 0,
+                               tags,
+                               message,
+                               arguments);
     }
 
     if (tags)
