@@ -1,7 +1,7 @@
 /*
  * irc-sasl.c - SASL authentication with IRC server
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <limits.h>
@@ -72,7 +72,14 @@ irc_sasl_mechanism_plain (const char *sasl_username, const char *sasl_password)
 
         answer_base64 = malloc (length * 4);
         if (answer_base64)
-            weechat_string_encode_base64 (string, length - 1, answer_base64);
+        {
+            if (weechat_string_base_encode (64, string, length - 1,
+                                            answer_base64) < 0)
+            {
+                free (answer_base64);
+                answer_base64 = NULL;
+            }
+        }
 
         free (string);
     }
@@ -89,8 +96,7 @@ irc_sasl_mechanism_plain (const char *sasl_username, const char *sasl_password)
 char *
 irc_sasl_get_key_content (struct t_irc_server *server, const char *sasl_key)
 {
-    const char *weechat_dir;
-    char *key_path1, *key_path2, *content;
+    char *weechat_dir, *key_path1, *key_path2, *content;
 
     if (!sasl_key)
         return NULL;
@@ -115,6 +121,8 @@ irc_sasl_get_key_content (struct t_irc_server *server, const char *sasl_key)
             (key_path2) ? key_path2 : ((key_path1) ? key_path1 : sasl_key));
     }
 
+    if (weechat_dir)
+        free (weechat_dir);
     if (key_path1)
         free (key_path1);
     if (key_path2)
@@ -173,7 +181,7 @@ irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
         data = malloc (strlen (data_base64) + 1);
         if (!data)
             return NULL;
-        length_data = weechat_string_decode_base64 (data_base64, data);
+        length_data = weechat_string_base_decode (64, data_base64, data);
 
         /* read file with private key */
         str_privkey = irc_sasl_get_key_content (server, sasl_key);
@@ -219,15 +227,17 @@ irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
                 pubkey_base64 = malloc ((x.size + 1 + 1) * 4);
                 if (pubkey_base64)
                 {
-                    weechat_string_encode_base64 (pubkey, x.size + 1,
-                                                  pubkey_base64);
-                    weechat_printf (
-                        server->buffer,
-                        _("%s%s: signing the challenge with ECC public key: "
-                          "%s"),
-                        weechat_prefix ("network"),
-                        IRC_PLUGIN_NAME,
-                        pubkey_base64);
+                    if (weechat_string_base_encode (64, pubkey, x.size + 1,
+                                                    pubkey_base64) >= 0)
+                    {
+                        weechat_printf (
+                            server->buffer,
+                            _("%s%s: signing the challenge with ECC public "
+                              "key: %s"),
+                            weechat_prefix ("network"),
+                            IRC_PLUGIN_NAME,
+                            pubkey_base64);
+                    }
                     free (pubkey_base64);
                 }
                 free (pubkey);
@@ -289,7 +299,14 @@ irc_sasl_mechanism_ecdsa_nist256p_challenge (struct t_irc_server *server,
     {
         answer_base64 = malloc ((length + 1) * 4);
         if (answer_base64)
-            weechat_string_encode_base64 (string, length, answer_base64);
+        {
+            if (weechat_string_base_encode (64, string, length,
+                                            answer_base64) < 0)
+            {
+                free (answer_base64);
+                answer_base64 = NULL;
+            }
+        }
         free (string);
         string = NULL;
     }
@@ -349,7 +366,7 @@ irc_sasl_dh (const char *data_base64,
     data = malloc (strlen (data_base64) + 1);
     if (!data)
 	goto dhend;
-    length_data = weechat_string_decode_base64 (data_base64, data);
+    length_data = weechat_string_base_decode (64, data_base64, data);
     ptr_data = (unsigned char *)data;
 
     /* extract prime number */
@@ -504,7 +521,14 @@ irc_sasl_mechanism_dh_blowfish (const char *data_base64,
     /* encode answer to base64 */
     answer_base64 = malloc ((length_answer + 1) * 4);
     if (answer_base64)
-        weechat_string_encode_base64 (answer, length_answer, answer_base64);
+    {
+        if (weechat_string_base_encode (64, answer, length_answer,
+                                        answer_base64) < 0)
+        {
+            free (answer_base64);
+            answer_base64 = NULL;
+        }
+    }
 
 bfend:
     if (secret_bin)
@@ -626,7 +650,14 @@ irc_sasl_mechanism_dh_aes (const char *data_base64,
     /* encode answer to base64 */
     answer_base64 = malloc ((length_answer + 1) * 4);
     if (answer_base64)
-        weechat_string_encode_base64 (answer, length_answer, answer_base64);
+    {
+        if (weechat_string_base_encode (64, answer, length_answer,
+                                        answer_base64) < 0)
+        {
+            free (answer_base64);
+            answer_base64 = NULL;
+        }
+    }
 
 aesend:
     if (secret_bin)
