@@ -32,7 +32,7 @@
  */
 
 #ifndef WEECHAT_PLUGIN_PHP_API_H
-#define WEECHAT_PLUGIN_PHP_API_H 1
+#define WEECHAT_PLUGIN_PHP_API_H
 
 extern struct zval* weechat_php_api_funcs[];
 extern struct t_php_const weechat_php_api_consts[];
@@ -54,6 +54,7 @@ PHP_FUNCTION(weechat_gettext);
 PHP_FUNCTION(weechat_ngettext);
 PHP_FUNCTION(weechat_strlen_screen);
 PHP_FUNCTION(weechat_string_match);
+PHP_FUNCTION(weechat_string_match_list);
 PHP_FUNCTION(weechat_string_has_highlight);
 PHP_FUNCTION(weechat_string_has_highlight_regex);
 PHP_FUNCTION(weechat_string_mask_to_regex);
@@ -196,6 +197,7 @@ PHP_FUNCTION(weechat_bar_set);
 PHP_FUNCTION(weechat_bar_update);
 PHP_FUNCTION(weechat_bar_remove);
 PHP_FUNCTION(weechat_command);
+PHP_FUNCTION(weechat_command_options);
 PHP_FUNCTION(weechat_info_get);
 PHP_FUNCTION(weechat_info_get_hashtable);
 PHP_FUNCTION(weechat_infolist_new);
