@@ -2,7 +2,7 @@
  * weechat-php.c - PHP plugin for WeeChat
  *
  * Copyright (C) 2006-2017 Adam Saponara <as@php.net>
- * Copyright (C) 2017-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2017-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,7 +17,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  *
  * OpenSSL licensing:
  *
@@ -65,7 +65,6 @@ int php_eval_mode = 0;
 int php_eval_send_input = 0;
 int php_eval_exec_commands = 0;
 struct t_gui_buffer *php_eval_buffer = NULL;
-char *php_eval_output = NULL;
 
 struct t_plugin_script *php_scripts = NULL;
 struct t_plugin_script *last_php_script = NULL;
@@ -108,6 +107,7 @@ const zend_function_entry weechat_functions[] = {
     PHP_FE(weechat_ngettext, NULL)
     PHP_FE(weechat_strlen_screen, NULL)
     PHP_FE(weechat_string_match, NULL)
+    PHP_FE(weechat_string_match_list, NULL)
     PHP_FE(weechat_string_has_highlight, NULL)
     PHP_FE(weechat_string_has_highlight_regex, NULL)
     PHP_FE(weechat_string_mask_to_regex, NULL)
@@ -250,6 +250,7 @@ const zend_function_entry weechat_functions[] = {
     PHP_FE(weechat_bar_update, NULL)
     PHP_FE(weechat_bar_remove, NULL)
     PHP_FE(weechat_command, NULL)
+    PHP_FE(weechat_command_options, NULL)
     PHP_FE(weechat_info_get, NULL)
     PHP_FE(weechat_info_get_hashtable, NULL)
     PHP_FE(weechat_infolist_new, NULL)
@@ -1060,12 +1061,12 @@ weechat_php_hdata_cb (const void *pointer, void *data,
  * Returns PHP info "php_eval".
  */
 
-const char *
+char *
 weechat_php_info_eval_cb (const void *pointer, void *data,
                           const char *info_name,
                           const char *arguments)
 {
-    static const char *not_implemented = "not yet implemented";
+    const char *not_implemented = "not yet implemented";
 
     /* make C compiler happy */
     (void) pointer;
@@ -1073,7 +1074,7 @@ weechat_php_info_eval_cb (const void *pointer, void *data,
     (void) info_name;
     (void) arguments;
 
-    return not_implemented;
+    return strdup (not_implemented);
 }
 
 /*
@@ -1349,8 +1350,6 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
     if (php_action_autoload_list)
         free (php_action_autoload_list);
     /* weechat_string_dyn_free (php_buffer_output, 1); */
-    if (php_eval_output)
-        free (php_eval_output);
 
     return WEECHAT_RC_OK;
 }
