@@ -273,12 +273,14 @@ plugin_get_args (struct t_weechat_plugin *plugin,
                  int argc, char **argv,
                  int *plugin_argc, char ***plugin_argv)
 {
-    int i, temp_argc;
+    int i, temp_argc, length_plugin_name;
     char **temp_argv;
 
     temp_argc = 0;
     temp_argv = NULL;
 
+    length_plugin_name = strlen (plugin->name);
+
     if (argc > 0)
     {
         temp_argv = malloc ((argc + 1) * sizeof (*temp_argv));
@@ -290,9 +292,9 @@ plugin_get_args (struct t_weechat_plugin *plugin,
                     || (strcmp (argv[i], "--no-connect") == 0)
                     || (strcmp (argv[i], "-s") == 0)
                     || (strcmp (argv[i], "--no-script") == 0)
-                    || (strcmp (argv[i], "--upgrade") == 0)
-                    || (strncmp (argv[i], plugin->name,
-                                 strlen (plugin->name)) == 0))
+                    || ((strncmp (argv[i], plugin->name,
+                                  length_plugin_name) == 0)
+                        && (argv[i][length_plugin_name] == ':')))
                 {
                     temp_argv[temp_argc++] = argv[i];
                 }
@@ -572,6 +574,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->initialized = 0;
         ptr_option = config_weechat_debug_get (name);
         new_plugin->debug = (ptr_option) ? CONFIG_INTEGER(ptr_option) : 0;
+        new_plugin->upgrading = weechat_upgrading;
         new_plugin->variables = hashtable_new (
             32,
             WEECHAT_HASHTABLE_STRING, WEECHAT_HASHTABLE_STRING,
@@ -669,6 +672,7 @@ plugin_load (const char *filename, int init_plugin, int argc, char **argv)
         new_plugin->list_next = &weelist_next;
         new_plugin->list_prev = &weelist_prev;
         new_plugin->list_string = &weelist_string;
+        new_plugin->list_user_data = &weelist_user_data;
         new_plugin->list_size = &weelist_size;
         new_plugin->list_remove = &weelist_remove;
         new_plugin->list_remove_all = &weelist_remove_all;
@@ -1007,6 +1011,7 @@ plugin_auto_load (char *force_plugin_autoload,
         plugin_autoload_array = string_split (
             ptr_plugin_autoload,
             ",",
+            NULL,
             WEECHAT_STRING_SPLIT_STRIP_LEFT
             | WEECHAT_STRING_SPLIT_STRIP_RIGHT
             | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -1401,6 +1406,7 @@ plugin_hdata_plugin_cb (const void *pointer, void *data,
         HDATA_VAR(struct t_weechat_plugin, priority, INTEGER, 0, NULL, NULL);
         HDATA_VAR(struct t_weechat_plugin, initialized, INTEGER, 0, NULL, NULL);
         HDATA_VAR(struct t_weechat_plugin, debug, INTEGER, 0, NULL, NULL);
+        HDATA_VAR(struct t_weechat_plugin, upgrading, INTEGER, 0, NULL, NULL);
         HDATA_VAR(struct t_weechat_plugin, variables, HASHTABLE, 0, NULL, NULL);
         HDATA_VAR(struct t_weechat_plugin, prev_plugin, POINTER, 0, NULL, hdata_name);
         HDATA_VAR(struct t_weechat_plugin, next_plugin, POINTER, 0, NULL, hdata_name);
@@ -1459,6 +1465,8 @@ plugin_add_to_infolist (struct t_infolist *infolist,
         return 0;
     if (!infolist_new_var_integer (ptr_item, "debug", plugin->debug))
         return 0;
+    if (!infolist_new_var_integer (ptr_item, "upgrading", plugin->upgrading))
+        return 0;
     if (!hashtable_add_to_infolist (plugin->variables, ptr_item, "var"))
         return 0;
 
@@ -1490,6 +1498,7 @@ plugin_print_log ()
         log_printf ("  priority . . . . . . . : %d",    ptr_plugin->priority);
         log_printf ("  initialized. . . . . . : %d",    ptr_plugin->initialized);
         log_printf ("  debug. . . . . . . . . : %d",    ptr_plugin->debug);
+        log_printf ("  upgrading. . . . . . . : %d",    ptr_plugin->upgrading);
         hashtable_print_log (ptr_plugin->variables, "variables");
         log_printf ("  prev_plugin. . . . . . : 0x%lx", ptr_plugin->prev_plugin);
         log_printf ("  next_plugin. . . . . . : 0x%lx", ptr_plugin->next_plugin);
