@@ -337,7 +337,11 @@ relay_irc_tag_relay_client_id (const char *tags)
 
     if (tags && tags[0])
     {
-        argv = weechat_string_split (tags, ",", 0, 0, &argc);
+        argv = weechat_string_split (tags, ",", NULL,
+                                     WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                     | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                     | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                     0, &argc);
         if (argv)
         {
             for (i = 0; i < argc; i++)
@@ -561,7 +565,11 @@ relay_irc_hsignal_irc_redir_cb (const void *pointer, void *data,
     if (!output)
         return WEECHAT_RC_OK;
 
-    messages = weechat_string_split (output, "\n", 0, 0, &num_messages);
+    messages = weechat_string_split (output, "\n", NULL,
+                                     WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                     | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                     | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                     0, &num_messages);
     if (messages)
     {
         for (i = 0; i < num_messages; i++)
@@ -1314,11 +1322,12 @@ relay_irc_recv_command_capab (struct t_relay_client *client,
 void
 relay_irc_recv (struct t_relay_client *client, const char *data)
 {
-    char str_time[128], str_signal[128], str_server_channel[256];
-    char str_command[128], *target, **irc_argv, **irc_argv_eol, *pos, *password;
+    char str_time[128], str_signal[128], str_server_channel[256], *nick;
+    char *version, str_command[128], *target, **irc_argv, **irc_argv_eol;
+    char *pos, *password, *irc_is_channel, *info;
     const char *irc_command, *irc_channel, *irc_args, *irc_args2;
     int irc_argc, redirect_msg;
-    const char *nick, *irc_is_channel, *isupport, *info, *pos_password;
+    const char *isupport, *pos_password;
     struct t_hashtable *hash_parsed, *hash_redirect;
     struct t_infolist *infolist_server;
 
@@ -1347,8 +1356,25 @@ relay_irc_recv (struct t_relay_client *client, const char *data)
     irc_args = weechat_hashtable_get (hash_parsed, "arguments");
     if (irc_args)
     {
-        irc_argv = weechat_string_split (irc_args, " ", 0, 0, &irc_argc);
-        irc_argv_eol = weechat_string_split (irc_args, " ", 1, 0, NULL);
+        irc_argv = weechat_string_split (
+            irc_args,
+            " ",
+            NULL,
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &irc_argc);
+        irc_argv_eol = weechat_string_split (
+            irc_args,
+            " ",
+            NULL,
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
+            | WEECHAT_STRING_SPLIT_KEEP_EOL,
+            0,
+            NULL);
     }
 
     /*
@@ -1489,7 +1515,10 @@ relay_irc_recv (struct t_relay_client *client, const char *data)
                 free (RELAY_IRC_DATA(client, nick));
                 RELAY_IRC_DATA(client, nick) = strdup (nick);
             }
+            if (nick)
+                free (nick);
 
+            version = weechat_info_get ("version", NULL);
             relay_irc_sendf (client,
                              ":%s 001 %s :Welcome to the Internet "
                              "Relay Chat Network %s!%s@proxy",
@@ -1502,7 +1531,7 @@ relay_irc_recv (struct t_relay_client *client, const char *data)
                              "weechat-relay-irc, running version %s",
                              RELAY_IRC_DATA(client, address),
                              RELAY_IRC_DATA(client, nick),
-                             weechat_info_get ("version", NULL));
+                             version);
             snprintf (str_time, sizeof (str_time), "%s",
                       ctime (&client->listen_start_time));
             if (str_time[0])
@@ -1517,7 +1546,9 @@ relay_irc_recv (struct t_relay_client *client, const char *data)
                              RELAY_IRC_DATA(client, address),
                              RELAY_IRC_DATA(client, nick),
                              RELAY_IRC_DATA(client, address),
-                             weechat_info_get ("version", NULL));
+                             version);
+            if (version)
+                free (version);
             infolist_server = weechat_infolist_get ("irc_server", NULL,
                                                     client->protocol_args);
             if (infolist_server)
@@ -1628,6 +1659,8 @@ relay_irc_recv (struct t_relay_client *client, const char *data)
                                       "/query %s %s",
                                       irc_channel, irc_args2);
             }
+            if (irc_is_channel)
+                free (irc_is_channel);
         }
         else if (!relay_irc_command_ignored (irc_command))
         {
@@ -1698,6 +1731,8 @@ relay_irc_recv (struct t_relay_client *client, const char *data)
                                                        "mode_user");
                             }
                         }
+                        if (info)
+                            free (info);
                     }
                 }
                 else if (weechat_strcasecmp (irc_command, "ison") == 0)
