@@ -134,7 +134,7 @@ relay_command_server_list ()
     if (relay_servers)
     {
         weechat_printf (NULL, "");
-        weechat_printf (NULL, _("Listening on ports:"));
+        weechat_printf (NULL, _("Listening on:"));
         i = 1;
         for (ptr_server = relay_servers; ptr_server;
              ptr_server = ptr_server->next_server)
@@ -143,14 +143,15 @@ relay_command_server_list ()
             {
                 weechat_printf (
                     NULL,
-                    _("  port %s%d%s, relay: %s%s%s, %s (not started)"),
+                    _("  %s %s%s%s, relay: %s%s%s, %s (not started)"),
+                    (ptr_server->unix_socket) ? _("path") : _("port"),
                     RELAY_COLOR_CHAT_BUFFER,
-                    ptr_server->port,
+                    ptr_server->path,
                     RELAY_COLOR_CHAT,
                     RELAY_COLOR_CHAT_BUFFER,
                     ptr_server->protocol_string,
                     RELAY_COLOR_CHAT,
-                    ((ptr_server->ipv4 && ptr_server->ipv6) ? "IPv4+6" : ((ptr_server->ipv6) ? "IPv6" : "IPv4")));
+                    ((ptr_server->ipv4 && ptr_server->ipv6) ? "IPv4+6" : ((ptr_server->ipv6) ? "IPv6" : ((ptr_server->ipv4) ? "IPv4" : "UNIX"))));
             }
             else
             {
@@ -164,14 +165,15 @@ relay_command_server_list ()
                 }
                 weechat_printf (
                     NULL,
-                    _("  port %s%d%s, relay: %s%s%s, %s, started on: %s"),
+                    _("  %s %s%s%s, relay: %s%s%s, %s, started on: %s"),
+                    (ptr_server->unix_socket) ? _("path") : _("port"),
                     RELAY_COLOR_CHAT_BUFFER,
-                    ptr_server->port,
+                    ptr_server->path,
                     RELAY_COLOR_CHAT,
                     RELAY_COLOR_CHAT_BUFFER,
                     ptr_server->protocol_string,
                     RELAY_COLOR_CHAT,
-                    ((ptr_server->ipv4 && ptr_server->ipv6) ? "IPv4+6" : ((ptr_server->ipv6) ? "IPv6" : "IPv4")),
+                    ((ptr_server->ipv4 && ptr_server->ipv6) ? "IPv4+6" : ((ptr_server->ipv6) ? "IPv6" : ((ptr_server->ipv4) ? "IPv4" : "UNIX"))),
                     date_start);
             }
             i++;
@@ -192,7 +194,8 @@ relay_command_relay (const void *pointer, void *data,
 {
     struct t_relay_server *ptr_server;
     struct t_config_option *ptr_option;
-    int port;
+    char *path;
+    int unix_socket, rc;
 
     /* make C compiler happy */
     (void) pointer;
@@ -222,17 +225,22 @@ relay_command_relay (const void *pointer, void *data,
         if (weechat_strcasecmp (argv[1], "add") == 0)
         {
             WEECHAT_COMMAND_MIN_ARGS(4, "add");
-            if (relay_config_create_option_port (
-                    NULL, NULL,
-                    relay_config_file,
-                    relay_config_section_port,
-                    argv[2],
-                    argv_eol[3]) != WEECHAT_CONFIG_OPTION_SET_ERROR)
+            relay_server_get_protocol_args (argv[2], NULL, NULL, NULL,
+                                            &unix_socket, NULL, NULL);
+            rc = relay_config_create_option_port_path (
+                NULL, NULL,
+                relay_config_file,
+                (unix_socket) ? relay_config_section_path : relay_config_section_port,
+                argv[2],
+                argv_eol[3]);
+            if (rc != WEECHAT_CONFIG_OPTION_SET_ERROR)
             {
                 weechat_printf (NULL,
-                                _("%s: relay \"%s\" (port %s) added"),
+                                _("%s: relay \"%s\" (%s: %s) added"),
                                 RELAY_PLUGIN_NAME,
-                                argv[2], argv_eol[3]);
+                                argv[2],
+                                (unix_socket) ? _("path") : _("port"),
+                                argv_eol[3]);
             }
             return WEECHAT_RC_OK;
         }
@@ -243,17 +251,22 @@ relay_command_relay (const void *pointer, void *data,
             ptr_server = relay_server_search (argv_eol[2]);
             if (ptr_server)
             {
-                port = ptr_server->port;
+                unix_socket = ptr_server->unix_socket;
+                path = strdup (ptr_server->path);
                 relay_server_free (ptr_server);
-                ptr_option = weechat_config_search_option (relay_config_file,
-                                                           relay_config_section_port,
-                                                           argv_eol[2]);
+                ptr_option = weechat_config_search_option (
+                    relay_config_file,
+                    (unix_socket) ? relay_config_section_path : relay_config_section_port,
+                    argv_eol[2]);
                 if (ptr_option)
                     weechat_config_option_free (ptr_option);
                 weechat_printf (NULL,
-                                _("%s: relay \"%s\" (port %d) removed"),
+                                _("%s: relay \"%s\" (%s: %s) removed"),
                                 RELAY_PLUGIN_NAME,
-                                argv[2], port);
+                                argv[2],
+                                (unix_socket) ? _("path") : _("port"),
+                                path);
+                free (path);
             }
             else
             {
@@ -384,14 +397,14 @@ relay_command_init ()
         "relay",
         N_("relay control"),
         N_("list|listfull|listrelay"
-           " || add <name> <port>"
+           " || add <name> <port>|<path>"
            " || del|start|restart|stop <name>"
            " || raw"
            " || sslcertkey"),
         N_("         list: list relay clients (only active relays)\n"
            "     listfull: list relay clients (verbose, all relays)\n"
            "    listrelay: list relays (name and port)\n"
-           "          add: add a relay (listen on a port)\n"
+           "          add: add a relay (listen on a port/path)\n"
            "          del: remove a relay (clients remain connected)\n"
            "        start: listen on port\n"
            "      restart: close the server socket and listen again on port "
@@ -399,14 +412,19 @@ relay_command_init ()
            "         stop: close the server socket (clients remain connected)\n"
            "         name: relay name (see format below)\n"
            "         port: port used for relay\n"
+           "         path: path used for relay (for UNIX domain socket only); "
+           "\"%h\" at beginning of string is replaced by WeeChat home "
+           "(\"~/.weechat\" by default), content is evaluated (see /help eval)\n"
            "          raw: open buffer with raw Relay data\n"
            "   sslcertkey: set SSL certificate/key using path in option "
            "relay.network.ssl_cert_key\n"
            "\n"
-           "Relay name is: [ipv4.][ipv6.][ssl.]<protocol.name>\n"
+           "Relay name is: [ipv4.][ipv6.][ssl.]<protocol.name> or "
+           "unix.[ssl.]<protocol.name>\n"
            "         ipv4: force use of IPv4\n"
            "         ipv6: force use of IPv6\n"
            "          ssl: enable SSL\n"
+           "         unix: use UNIX domain socket\n"
            "protocol.name: protocol and name to relay:\n"
            "                 - protocol \"irc\": name is the server to share "
            "(optional, if not given, the server name must be sent by client in "
@@ -437,7 +455,9 @@ relay_command_init ()
            "  weechat protocol with SSL, using only IPv6:\n"
            "    /relay add ipv6.ssl.weechat 9001\n"
            "  weechat protocol with SSL, using IPv4 + IPv6:\n"
-           "    /relay add ipv4.ipv6.ssl.weechat 9001"),
+           "    /relay add ipv4.ipv6.ssl.weechat 9001\n"
+           "  weechat protocol over UNIX domain socket:\n"
+           "    /relay add unix.weechat %h/relay_socket"),
         "list %(relay_relays)"
         " || listfull %(relay_relays)"
         " || listrelay"
