@@ -1,7 +1,7 @@
 /*
  * relay-server.c - server functions for relay plugin
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -26,10 +26,12 @@
 #include <time.h>
 #include <fcntl.h>
 #include <errno.h>
+#include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#include <sys/un.h>
 
 #include "../weechat-plugin.h"
 #include "relay.h"
@@ -49,17 +51,18 @@ struct t_relay_server *last_relay_server = NULL;
  *
  * Examples:
  *
- *   string                    ipv4 ipv6 ssl protocol protocol_args
+ *   string                    ipv4 ipv6 ssl unix protocol protocol_args
  *   ---------------------------------------------------------------
- *   irc.freenode              1    1    0   irc      freenode
- *   ssl.irc.freenode          1    1    1   irc      freenode
- *   ipv4.irc.freenode         1    0    0   irc      freenode
- *   ipv6.irc.freenode         0    1    0   irc      freenode
- *   ipv4.ipv6.irc.freenode    1    1    0   irc      freenode
- *   ipv6.ssl.irc.freenode     0    1    1   irc      freenode
- *   weechat                   1    1    0   weechat
- *   ssl.weechat               1    1    1   weechat
- *   ipv6.ssl.weechat          0    1    1   weechat
+ *   irc.freenode              1    1    0   0    irc      freenode
+ *   ssl.irc.freenode          1    1    1   0    irc      freenode
+ *   ipv4.irc.freenode         1    0    0   0    irc      freenode
+ *   ipv6.irc.freenode         0    1    0   0    irc      freenode
+ *   ipv4.ipv6.irc.freenode    1    1    0   0    irc      freenode
+ *   ipv6.ssl.irc.freenode     0    1    1   0    irc      freenode
+ *   weechat                   1    1    0   0    weechat
+ *   ssl.weechat               1    1    1   0    weechat
+ *   ipv6.ssl.weechat          0    1    1   0    weechat
+ *   unix.weechat              0    0    0   1    weechat
  *
  * Note: *protocol and *protocol_args must be freed after use.
  */
@@ -67,14 +70,16 @@ struct t_relay_server *last_relay_server = NULL;
 void
 relay_server_get_protocol_args (const char *protocol_and_args,
                                 int *ipv4, int *ipv6, int *ssl,
+                                int *unix_socket,
                                 char **protocol, char **protocol_args)
 {
-    int opt_ipv4, opt_ipv6, opt_ssl;
+    int opt_ipv4, opt_ipv6, opt_ssl, opt_unix_socket;
     char *pos;
 
     opt_ipv4 = -1;
     opt_ipv6 = -1;
     opt_ssl = 0;
+    opt_unix_socket = -1;
     while (1)
     {
         if (strncmp (protocol_and_args, "ipv4.", 5) == 0)
@@ -92,18 +97,24 @@ relay_server_get_protocol_args (const char *protocol_and_args,
             opt_ssl = 1;
             protocol_and_args += 4;
         }
+        else if (strncmp (protocol_and_args, "unix.", 5) == 0)
+        {
+            opt_unix_socket = 1;
+            protocol_and_args += 5;
+        }
         else
             break;
     }
-    if ((opt_ipv4 == -1) && (opt_ipv6 == -1))
+    if ((opt_ipv4 == -1) && (opt_ipv6 == -1) && (opt_unix_socket == -1))
     {
         /*
-         * no IPv4/IPv6 specified, then use defaults:
+         * no IPv4/IPv6/UNIX specified, then use defaults:
          * - IPv4 enabled
          * - IPv6 enabled if option relay.network.ipv6 is on
          */
         opt_ipv4 = 1;
         opt_ipv6 = weechat_config_boolean (relay_config_network_ipv6);
+        opt_unix_socket = 0;
     }
     else
     {
@@ -111,10 +122,12 @@ relay_server_get_protocol_args (const char *protocol_and_args,
             opt_ipv4 = 0;
         if (opt_ipv6 == -1)
             opt_ipv6 = 0;
+        if (opt_unix_socket == -1)
+            opt_unix_socket = 0;
     }
-    if (!opt_ipv4 && !opt_ipv6)
+    if (!opt_ipv4 && !opt_ipv6 && !opt_unix_socket)
     {
-        /* both IPv4/IPv6 disabled (should never occur!) */
+        /* IPv4/IPv6/UNIX disabled (should never occur!) */
         opt_ipv4 = 1;
     }
     if (ipv4)
@@ -123,6 +136,8 @@ relay_server_get_protocol_args (const char *protocol_and_args,
         *ipv6 = opt_ipv6;
     if (ssl)
         *ssl = opt_ssl;
+    if (unix_socket)
+        *unix_socket = opt_unix_socket;
 
     pos = strchr (protocol_and_args, '.');
     if (pos)
@@ -187,6 +202,28 @@ relay_server_search_port (int port)
     return NULL;
 }
 
+/*
+ * Searches for a server by path. Only returns servers using a UNIX socket.
+ *
+ * Returns pointer to new server, NULL if not found.
+ */
+
+struct t_relay_server *
+relay_server_search_path (const char *path)
+{
+    struct t_relay_server *ptr_server;
+
+    for (ptr_server = relay_servers; ptr_server;
+         ptr_server = ptr_server->next_server)
+    {
+        /* only include UNIX socket relays, to allow for numerical paths */
+        if (ptr_server->unix_socket && (strcmp (path, ptr_server->path) == 0))
+            return ptr_server;
+    }
+
+    /* server not found */
+    return NULL;
+}
 /*
  * Closes socket for a relay server.
  */
@@ -203,13 +240,16 @@ relay_server_close_socket (struct t_relay_server *server)
     {
         close (server->sock);
         server->sock = -1;
-
+        if (server->unix_socket)
+            unlink (server->path);
         if (!relay_signal_upgrade_received)
         {
             weechat_printf (NULL,
-                            _("%s: socket closed for %s (port %d)"),
-                            RELAY_PLUGIN_NAME, server->protocol_string,
-                            server->port);
+                            _("%s: socket closed for %s (%s: %s)"),
+                            RELAY_PLUGIN_NAME,
+                            server->protocol_string,
+                            (server->unix_socket) ? _("path") : _("port"),
+                            server->path);
         }
     }
 }
@@ -224,17 +264,22 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
     struct t_relay_server *server;
     struct sockaddr_in client_addr;
     struct sockaddr_in6 client_addr6;
+    struct sockaddr_un client_addr_unix;
     socklen_t client_addr_size;
     void *ptr_addr;
     int client_fd, flags, set, max_clients, num_clients_on_port;
     char ipv4_address[INET_ADDRSTRLEN + 1], ipv6_address[INET6_ADDRSTRLEN + 1];
-    char *ptr_ip_address;
-    const char *relay_password;
+    char unix_address[sizeof (client_addr_unix.sun_path)];
+    char *ptr_ip_address, *relay_password, *relay_totp_secret;
 
     /* make C compiler happy */
     (void) data;
     (void) fd;
 
+    client_fd = -1;
+    relay_password = NULL;
+    relay_totp_secret = NULL;
+
     server = (struct t_relay_server *)pointer;
 
     if (server->ipv6)
@@ -242,11 +287,16 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
         ptr_addr = &client_addr6;
         client_addr_size = sizeof (struct sockaddr_in6);
     }
-    else
+    else if (server->ipv4)
     {
         ptr_addr = &client_addr;
         client_addr_size = sizeof (struct sockaddr_in);
     }
+    else
+    {
+        ptr_addr = &client_addr_unix;
+        client_addr_size = sizeof (struct sockaddr_un);
+    }
 
     memset (ptr_addr, 0, client_addr_size);
 
@@ -254,12 +304,25 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
                         &client_addr_size);
     if (client_fd < 0)
     {
-        weechat_printf (NULL,
-                        _("%s%s: cannot accept client on port %d (%s): error %d %s"),
-                        weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                        server->port, server->protocol_string,
-                        errno, strerror (errno));
-        return WEECHAT_RC_OK;
+        if (server->unix_socket)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot accept client on path %s (%s): "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            server->path, server->protocol_string,
+                            errno, strerror (errno));
+        }
+        else
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot accept client on port %d (%s): "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            server->port, server->protocol_string,
+                            errno, strerror (errno));
+        }
+        goto error;
     }
 
     /* check if relay password is empty and if it is not allowed */
@@ -274,8 +337,34 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
                           "is empty, and option "
                           "relay.network.allow_empty_password is off"),
                         weechat_prefix ("error"), RELAY_PLUGIN_NAME);
-        close (client_fd);
-        return WEECHAT_RC_OK;
+        goto error;
+    }
+
+    if (server->protocol == RELAY_PROTOCOL_WEECHAT)
+    {
+        /*
+         * TOTP can be enabled only as second factor, in addition to the
+         * password (only for weechat protocol)
+         */
+        relay_totp_secret = weechat_string_eval_expression (
+            weechat_config_string (relay_config_network_totp_secret),
+            NULL, NULL, NULL);
+        if ((!relay_password || !relay_password[0])
+            && relay_totp_secret && relay_totp_secret[0])
+        {
+            weechat_printf (NULL,
+                            _("%s%s: Time-based One-Time Password (TOTP) "
+                              "can be enabled only as second factor, if the "
+                              "password is not empty"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME);
+            goto error;
+        }
+        if (!relay_config_check_network_totp_secret (
+                NULL, NULL, NULL,
+                weechat_config_string (relay_config_network_totp_secret)))
+        {
+            goto error;
+        }
     }
 
     /* check if we have reached the max number of clients on this port */
@@ -294,8 +383,7 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
                     max_clients),
                 weechat_prefix ("error"), RELAY_PLUGIN_NAME,
                 max_clients);
-            close (client_fd);
-            return WEECHAT_RC_OK;
+            goto error;
         }
     }
 
@@ -317,7 +405,7 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
             }
         }
     }
-    else
+    else if (server->ipv4)
     {
         if (inet_ntop (AF_INET,
                        &(client_addr.sin_addr),
@@ -327,6 +415,13 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
             ptr_ip_address = ipv4_address;
         }
     }
+    else
+    {
+        snprintf (unix_address, sizeof (unix_address),
+                  "%s",
+                  client_addr_unix.sun_path);
+        ptr_ip_address = unix_address;
+    }
 
     /* check if IP is allowed, if not, just close socket */
     if (relay_config_regex_allowed_ips
@@ -340,8 +435,7 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
                             RELAY_PLUGIN_NAME,
                             ptr_ip_address);
         }
-        close (client_fd);
-        return WEECHAT_RC_OK;
+        goto error;
     }
 
     /* set non-blocking mode for socket */
@@ -350,23 +444,37 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
         flags = 0;
     fcntl (client_fd, F_SETFL, flags | O_NONBLOCK);
 
-    /* set socket option SO_REUSEADDR */
-    set = 1;
-    if (setsockopt (client_fd, SOL_SOCKET, SO_REUSEADDR,
-                    (void *) &set, sizeof (set)) < 0)
+    /* set socket option SO_REUSEADDR (only for TCP socket) */
+    if (!server->unix_socket)
     {
-        weechat_printf (NULL,
-                        _("%s%s: cannot set socket option \"%s\" to %d: "
-                          "error %d %s"),
-                        weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                        "SO_REUSEADDR", set, errno, strerror (errno));
-        close (client_fd);
-        return WEECHAT_RC_OK;
+        set = 1;
+        if (setsockopt (client_fd, SOL_SOCKET, SO_REUSEADDR,
+                        (void *) &set, sizeof (set)) < 0)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot set socket option \"%s\" to %d: "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            "SO_REUSEADDR", set, errno, strerror (errno));
+            goto error;
+        }
     }
 
     /* add the client */
     relay_client_new (client_fd, ptr_ip_address, server);
 
+    goto end;
+
+error:
+    if (client_fd >= 0)
+        close (client_fd);
+
+end:
+    if (relay_password)
+        free (relay_password);
+    if (relay_totp_secret)
+        free (relay_totp_secret);
+
     return WEECHAT_RC_OK;
 }
 
@@ -381,9 +489,10 @@ relay_server_sock_cb (const void *pointer, void *data, int fd)
 int
 relay_server_create_socket (struct t_relay_server *server)
 {
-    int domain, set, max_clients, addr_size;
+    int domain, set, max_clients, addr_size, rc;
     struct sockaddr_in server_addr;
     struct sockaddr_in6 server_addr6;
+    struct sockaddr_un server_addr_unix;
     const char *bind_address;
     void *ptr_addr;
 
@@ -411,7 +520,7 @@ relay_server_create_socket (struct t_relay_server *server)
         ptr_addr = &server_addr6;
         addr_size = sizeof (struct sockaddr_in6);
     }
-    else
+    else if (server->ipv4)
     {
         domain = AF_INET;
         memset (&server_addr, 0, sizeof (struct sockaddr_in));
@@ -433,6 +542,47 @@ relay_server_create_socket (struct t_relay_server *server)
         ptr_addr = &server_addr;
         addr_size = sizeof (struct sockaddr_in);
     }
+    else
+    {
+        domain = AF_UNIX;
+        memset (&server_addr_unix, 0, sizeof (struct sockaddr_un));
+        server_addr_unix.sun_family = domain;
+        snprintf (server_addr_unix.sun_path,
+                  sizeof (server_addr_unix.sun_path),
+                  "%s",
+                  server->path);
+        ptr_addr = &server_addr_unix;
+        addr_size = sizeof (struct sockaddr_un);
+        if (!relay_config_check_path_length (server->path))
+        {
+            weechat_printf (NULL,
+                            _("%s%s: socket path \"%s\" is invalid"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            server->path);
+            return 0;
+        }
+        rc = relay_config_check_path_available (server->path);
+        switch (rc)
+        {
+            case -1:
+                weechat_printf (NULL,
+                                _("%s%s: socket path \"%s\" already exists "
+                                  "and is not a socket"),
+                                weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                                server->path);
+                break;
+            case -2:
+                weechat_printf (NULL,
+                                _("%s%s: socket path \"%s\" is invalid"),
+                                weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                                server->path);
+        }
+        if (rc < 0)
+            return 0;
+        /* just in case a socket already exists */
+        unlink (server->path);
+    }
+
 
     /* create socket */
     server->sock = socket (domain, SOCK_STREAM, 0);
@@ -471,60 +621,96 @@ relay_server_create_socket (struct t_relay_server *server)
     }
 #endif
 
-    /* set option SO_REUSEADDR to 1 */
-    set = 1;
-    if (setsockopt (server->sock, SOL_SOCKET, SO_REUSEADDR,
-                    (void *) &set, sizeof (set)) < 0)
+    /* set option SO_REUSEADDR to 1 (only for TCP socket) */
+    if (!server->unix_socket)
     {
-        weechat_printf (NULL,
-                        _("%s%s: cannot set socket option \"%s\" to %d: "
-                          "error %d %s"),
-                        weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                        "SO_REUSEADDR", set, errno, strerror (errno));
-        close (server->sock);
-        server->sock = -1;
-        return 0;
+        set = 1;
+        if (setsockopt (server->sock, SOL_SOCKET, SO_REUSEADDR,
+                        (void *) &set, sizeof (set)) < 0)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot set socket option \"%s\" to %d: "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            "SO_REUSEADDR", set, errno, strerror (errno));
+            close (server->sock);
+            server->sock = -1;
+            return 0;
+        }
     }
 
-    /* set option SO_KEEPALIVE to 1 */
-    set = 1;
-    if (setsockopt (server->sock, SOL_SOCKET, SO_KEEPALIVE,
-                    (void *) &set, sizeof (set)) < 0)
+    /* set option SO_KEEPALIVE to 1 (only for TCP socket) */
+    if (!server->unix_socket)
     {
-        weechat_printf (NULL,
-                        _("%s%s: cannot set socket option \"%s\" to %d: "
-                          "error %d %s"),
-                        weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                        "SO_KEEPALIVE", set, errno, strerror (errno));
-        close (server->sock);
-        server->sock = -1;
-        return 0;
+        set = 1;
+        if (setsockopt (server->sock, SOL_SOCKET, SO_KEEPALIVE,
+                        (void *) &set, sizeof (set)) < 0)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot set socket option \"%s\" to %d: "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            "SO_KEEPALIVE", set, errno, strerror (errno));
+            close (server->sock);
+            server->sock = -1;
+            return 0;
+        }
     }
 
     /* bind */
     if (bind (server->sock, (struct sockaddr *)ptr_addr, addr_size) < 0)
     {
-        weechat_printf (NULL,
-                        _("%s%s: cannot \"bind\" on port %d (%s): error %d %s"),
-                        weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                        server->port, server->protocol_string,
-                        errno, strerror (errno));
+        if (server->unix_socket)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot \"bind\" on path %s (%s): "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            server->path, server->protocol_string,
+                            errno, strerror (errno));
+        }
+        else
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot \"bind\" on port %d (%s): "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            server->port, server->protocol_string,
+                            errno, strerror (errno));
+        }
         close (server->sock);
         server->sock = -1;
         return 0;
     }
 
+    /* change permissions: only the owner can use the unix socket */
+    if (server->unix_socket)
+        chmod (server->path, 0700);
+
 #ifdef SOMAXCONN
     if (listen (server->sock, SOMAXCONN) != 0)
 #else
     if (listen (server->sock, 1) != 0)
 #endif
     {
-        weechat_printf (NULL,
-                        _("%s%s: cannot \"listen\" on port %d (%s): error %d %s"),
-                        weechat_prefix ("error"), RELAY_PLUGIN_NAME,
-                        server->port, server->protocol_string,
-                        errno, strerror (errno));
+        if (server->unix_socket)
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot \"listen\" on path %s (%s): "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            server->path, server->protocol_string,
+                            errno, strerror (errno));
+        }
+        else
+        {
+            weechat_printf (NULL,
+                            _("%s%s: cannot \"listen\" on port %d (%s): "
+                              "error %d %s"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            server->port, server->protocol_string,
+                            errno, strerror (errno));
+        }
         close (server->sock);
         server->sock = -1;
         return 0;
@@ -533,26 +719,55 @@ relay_server_create_socket (struct t_relay_server *server)
     max_clients = weechat_config_integer (relay_config_network_max_clients);
     if (max_clients > 0)
     {
-        weechat_printf (
-            NULL,
-            NG_("%s: listening on port %d (relay: %s, %s, max %d client)",
-                "%s: listening on port %d (relay: %s, %s, max %d clients)",
-                max_clients),
-            RELAY_PLUGIN_NAME,
-            server->port,
-            server->protocol_string,
-            ((server->ipv4 && server->ipv6) ? "IPv4+6" : ((server->ipv6) ? "IPv6" : "IPv4")),
-            max_clients);
+        if (server->unix_socket)
+        {
+            weechat_printf (
+                NULL,
+                NG_("%s: listening on path %s (relay: %s, %s, max %d client)",
+                    "%s: listening on path %s (relay: %s, %s, max %d clients)",
+                    max_clients),
+                RELAY_PLUGIN_NAME,
+                server->path,
+                server->protocol_string,
+                ((server->ipv4 && server->ipv6) ? "IPv4+6" : ((server->ipv6) ? "IPv6" : ((server->ipv4) ? "IPv4" : "UNIX"))),
+                max_clients);
+        }
+        else
+        {
+            weechat_printf (
+                NULL,
+                NG_("%s: listening on port %d (relay: %s, %s, max %d client)",
+                    "%s: listening on port %d (relay: %s, %s, max %d clients)",
+                    max_clients),
+                RELAY_PLUGIN_NAME,
+                server->port,
+                server->protocol_string,
+                ((server->ipv4 && server->ipv6) ? "IPv4+6" : ((server->ipv6) ? "IPv6" : ((server->ipv4) ? "IPv4" : "UNIX"))),
+                max_clients);
+        }
     }
     else
     {
-        weechat_printf (
-            NULL,
-            _("%s: listening on port %d (relay: %s, %s)"),
-            RELAY_PLUGIN_NAME,
-            server->port,
-            server->protocol_string,
-            ((server->ipv4 && server->ipv6) ? "IPv4+6" : ((server->ipv6) ? "IPv6" : "IPv4")));
+        if (server->unix_socket)
+        {
+            weechat_printf (
+                NULL,
+                _("%s: listening on path %s (relay: %s, %s)"),
+                RELAY_PLUGIN_NAME,
+                server->path,
+                server->protocol_string,
+                ((server->ipv4 && server->ipv6) ? "IPv4+6" : ((server->ipv6) ? "IPv6" : ((server->ipv4) ? "IPv4" : "UNIX"))));
+        }
+        else
+        {
+            weechat_printf (
+                NULL,
+                _("%s: listening on port %d (relay: %s, %s)"),
+                RELAY_PLUGIN_NAME,
+                server->port,
+                server->protocol_string,
+                ((server->ipv4 && server->ipv6) ? "IPv4+6" : ((server->ipv6) ? "IPv6" : ((server->ipv4) ? "IPv4" : "UNIX"))));
+        }
     }
     server->hook_fd = weechat_hook_fd (server->sock,
                                        1, 0, 0,
@@ -572,19 +787,31 @@ relay_server_create_socket (struct t_relay_server *server)
 
 struct t_relay_server *
 relay_server_new (const char *protocol_string, enum t_relay_protocol protocol,
-                  const char *protocol_args, int port, int ipv4, int ipv6,
-                  int ssl)
+                  const char *protocol_args, int port, const char *path,
+                  int ipv4, int ipv6, int ssl, int unix_socket)
 {
-    struct t_relay_server *new_server;
+    struct t_relay_server *new_server, *dup_server;
 
     if (!protocol_string)
         return NULL;
 
-    if (relay_server_search_port (port))
+    /* look for duplicate ports/paths */
+    dup_server = (unix_socket) ?
+        relay_server_search_path (path) : relay_server_search_port (port);
+    if (dup_server)
     {
-        weechat_printf (NULL, _("%s%s: error: port \"%d\" is already used"),
-                        weechat_prefix ("error"),
-                        RELAY_PLUGIN_NAME, port);
+        if (unix_socket)
+        {
+            weechat_printf (NULL, _("%s%s: error: path \"%s\" is already used"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            path);
+        }
+        else
+        {
+            weechat_printf (NULL, _("%s%s: error: port \"%d\" is already used"),
+                            weechat_prefix ("error"), RELAY_PLUGIN_NAME,
+                            port);
+        }
         return NULL;
     }
 
@@ -596,9 +823,12 @@ relay_server_new (const char *protocol_string, enum t_relay_protocol protocol,
         new_server->protocol_args =
             (protocol_args) ? strdup (protocol_args) : NULL;
         new_server->port = port;
+        new_server->path = weechat_string_eval_path_home (path,
+                                                          NULL, NULL, NULL);
         new_server->ipv4 = ipv4;
         new_server->ipv6 = ipv6;
         new_server->ssl = ssl;
+        new_server->unix_socket = unix_socket;
         new_server->sock = -1;
         new_server->hook_fd = NULL;
         new_server->start_time = 0;
@@ -624,6 +854,31 @@ relay_server_new (const char *protocol_string, enum t_relay_protocol protocol,
     return new_server;
 }
 
+/*
+ * Updates path in a server.
+ */
+
+void
+relay_server_update_path (struct t_relay_server *server, const char *path)
+{
+    char *new_path;
+
+    new_path = weechat_string_eval_path_home (path, NULL, NULL, NULL);
+    if (!new_path)
+        return;
+
+    if (strcmp (new_path, server->path) != 0)
+    {
+        relay_server_close_socket (server);
+        free (server->path);
+        server->path = strdup (new_path);
+        server->port = -1;
+        relay_server_create_socket (server);
+    }
+
+    free (new_path);
+}
+
 /*
  * Updates port in a server.
  */
@@ -631,10 +886,15 @@ relay_server_new (const char *protocol_string, enum t_relay_protocol protocol,
 void
 relay_server_update_port (struct t_relay_server *server, int port)
 {
+    char str_path[128];
+
     if (port != server->port)
     {
         relay_server_close_socket (server);
         server->port = port;
+        snprintf (str_path, sizeof (str_path), "%d", port);
+        free (server->path);
+        server->path = strdup (str_path);
         relay_server_create_socket (server);
     }
 }
@@ -670,6 +930,7 @@ relay_server_free (struct t_relay_server *server)
         free (server->protocol_string);
     if (server->protocol_args)
         free (server->protocol_args);
+    free (server->path);
 
     free (server);
 
@@ -718,12 +979,16 @@ relay_server_add_to_infolist (struct t_infolist *infolist,
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "port", server->port))
         return 0;
+    if (!weechat_infolist_new_var_string (ptr_item, "path", server->path))
+        return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "ipv4", server->ipv4))
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "ipv6", server->ipv6))
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "ssl", server->ssl))
         return 0;
+    if (!weechat_infolist_new_var_integer (ptr_item, "unix_socket", server->unix_socket))
+        return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "sock", server->sock))
         return 0;
     if (!weechat_infolist_new_var_pointer (ptr_item, "hook_fd", server->hook_fd))
@@ -756,9 +1021,11 @@ relay_server_print_log ()
                             relay_protocol_string[ptr_server->protocol]);
         weechat_log_printf ("  protocol_args . . . . : '%s'",  ptr_server->protocol_args);
         weechat_log_printf ("  port. . . . . . . . . : %d",    ptr_server->port);
+        weechat_log_printf ("  path. . . . . . . . . : %s",    ptr_server->path);
         weechat_log_printf ("  ipv4. . . . . . . . . : %d",    ptr_server->ipv4);
         weechat_log_printf ("  ipv6. . . . . . . . . : %d",    ptr_server->ipv6);
         weechat_log_printf ("  ssl . . . . . . . . . : %d",    ptr_server->ssl);
+        weechat_log_printf ("  unix_socket . . . . . : %d",    ptr_server->unix_socket);
         weechat_log_printf ("  sock. . . . . . . . . : %d",    ptr_server->sock);
         weechat_log_printf ("  hook_fd . . . . . . . : 0x%lx", ptr_server->hook_fd);
         weechat_log_printf ("  start_time. . . . . . : %lld",  (long long)ptr_server->start_time);
