@@ -187,8 +187,6 @@ relay_debug_dump_cb (const void *pointer, void *data,
 int
 weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 {
-    int i, upgrading;
-
     /* make C compiler happy */
     (void) argc;
     (void) argv;
@@ -212,17 +210,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 
     relay_info_init ();
 
-    /* look at arguments */
-    upgrading = 0;
-    for (i = 0; i < argc; i++)
-    {
-        if (weechat_strcasecmp (argv[i], "--upgrade") == 0)
-        {
-            upgrading = 1;
-        }
-    }
-
-    if (upgrading)
+    if (weechat_relay_plugin->upgrading)
         relay_upgrade_load ();
 
     relay_hook_timer = weechat_hook_timer (1 * 1000, 0, 0,
