@@ -1,7 +1,7 @@
 /*
  * relay-weechat-protocol.c - WeeChat protocol for relay to client
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -169,8 +169,8 @@ relay_weechat_protocol_is_sync (struct t_relay_client *ptr_client,
 
 RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
 {
-    char **options, *pos, *password;
-    int i, compression;
+    char **options, *pos, *password, *totp_secret, *info_totp_args, *info_totp;
+    int i, compression, length;
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(1);
 
@@ -186,20 +186,43 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
                 pos++;
                 if (strcmp (options[i], "password") == 0)
                 {
-                    password = weechat_string_eval_expression (weechat_config_string (relay_config_network_password),
-                                                               NULL, NULL, NULL);
+                    password = weechat_string_eval_expression (
+                        weechat_config_string (relay_config_network_password),
+                        NULL, NULL, NULL);
                     if (password)
                     {
                         if (strcmp (password, pos) == 0)
-                        {
                             RELAY_WEECHAT_DATA(client, password_ok) = 1;
-                            weechat_hook_signal_send ("relay_client_auth_ok",
-                                                      WEECHAT_HOOK_SIGNAL_POINTER,
-                                                      client);
-                        }
                         free (password);
                     }
                 }
+                else if (strcmp (options[i], "totp") == 0)
+                {
+                    totp_secret = weechat_string_eval_expression (
+                        weechat_config_string (relay_config_network_totp_secret),
+                        NULL, NULL, NULL);
+                    if (totp_secret)
+                    {
+                        length = strlen (totp_secret) + strlen (pos) + 16 + 1;
+                        info_totp_args = malloc (length);
+                        if (info_totp_args)
+                        {
+                            /* validate the OTP received from the client */
+                            snprintf (info_totp_args, length,
+                                      "%s,%s,0,%d",
+                                      totp_secret,  /* the shared secret */
+                                      pos,          /* the OTP from client */
+                                      weechat_config_integer (relay_config_network_totp_window));
+                            info_totp = weechat_info_get ("totp_validate", info_totp_args);
+                            if (info_totp && (strcmp (info_totp, "1") == 0))
+                                RELAY_WEECHAT_DATA(client, totp_ok) = 1;
+                            if (info_totp)
+                                free (info_totp);
+                            free (info_totp_args);
+                        }
+                        free (totp_secret);
+                    }
+                }
                 else if (strcmp (options[i], "compression") == 0)
                 {
                     compression = relay_weechat_compression_search (pos);
@@ -211,8 +234,17 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(init)
         weechat_string_free_split_command (options);
     }
 
-    if (!RELAY_WEECHAT_DATA(client, password_ok))
+    if (RELAY_WEECHAT_DATA(client, password_ok)
+        && RELAY_WEECHAT_DATA(client, totp_ok))
+    {
+        weechat_hook_signal_send ("relay_client_auth_ok",
+                                  WEECHAT_HOOK_SIGNAL_POINTER,
+                                  client);
+    }
+    else
+    {
         relay_client_set_status (client, RELAY_STATUS_AUTH_FAILED);
+    }
 
     return WEECHAT_RC_OK;
 }
@@ -259,7 +291,7 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(hdata)
 RELAY_WEECHAT_PROTOCOL_CALLBACK(info)
 {
     struct t_relay_weechat_msg *msg;
-    const char *info;
+    char *info;
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(1);
 
@@ -273,6 +305,8 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(info)
         relay_weechat_msg_add_string (msg, info);
         relay_weechat_msg_send (client, msg);
         relay_weechat_msg_free (msg);
+        if (info)
+            free (info);
     }
 
     return WEECHAT_RC_OK;
@@ -361,45 +395,6 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(nicklist)
     return WEECHAT_RC_OK;
 }
 
-/*
- * Timer callback for input command.
- */
-
-int
-relay_weechat_protocol_input_timer_cb (const void *pointer,
-                                       void *data,
-                                       int remaining_calls)
-{
-    char **timer_args;
-    int i;
-    struct t_gui_buffer *ptr_buffer;
-
-    /* make C compiler happy */
-    (void) data;
-    (void) remaining_calls;
-
-    timer_args = (char **)pointer;
-
-    if (!timer_args)
-        return WEECHAT_RC_ERROR;
-
-    if (timer_args[0] && timer_args[1])
-    {
-        ptr_buffer = weechat_buffer_search ("==", timer_args[0]);
-        if (ptr_buffer)
-            weechat_command (ptr_buffer, timer_args[1]);
-    }
-
-    for (i = 0; i < 2; i++)
-    {
-        if (timer_args[i])
-            free (timer_args[i]);
-    }
-    free (timer_args);
-
-    return WEECHAT_RC_OK;
-}
-
 /*
  * Callback for command "input" (from client).
  *
@@ -412,7 +407,9 @@ relay_weechat_protocol_input_timer_cb (const void *pointer,
 RELAY_WEECHAT_PROTOCOL_CALLBACK(input)
 {
     struct t_gui_buffer *ptr_buffer;
-    char *pos, **timer_args;
+    struct t_hashtable *options;
+    const char *ptr_weechat_commands;
+    char *pos;
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(1);
 
@@ -432,26 +429,43 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(input)
     }
 
     pos = strchr (argv_eol[0], ' ');
-    if (pos)
+    if (!pos)
+        return WEECHAT_RC_OK;
+
+    pos++;
+    options = weechat_hashtable_new (8,
+                                     WEECHAT_HASHTABLE_STRING,
+                                     WEECHAT_HASHTABLE_STRING,
+                                     NULL, NULL);
+    if (!options)
     {
-        /*
-         * use a timer to execute the command after we go back in the
-         * WeeChat main loop (some commands like /upgrade executed now can
-         * cause a crash)
-         */
-        timer_args = malloc (2 * sizeof (*timer_args));
-        if (timer_args)
-        {
-            timer_args[0] = strdup (weechat_buffer_get_string (ptr_buffer,
-                                                               "full_name"));
-            timer_args[1] = strdup (pos + 1);
-            weechat_hook_timer (1, 0, 1,
-                                &relay_weechat_protocol_input_timer_cb,
-                                timer_args,
-                                NULL);
-        }
+        weechat_printf (NULL,
+                        _("%s%s: not enough memory"),
+                        weechat_prefix ("error"), RELAY_PLUGIN_NAME);
+        return WEECHAT_RC_OK;
     }
 
+    ptr_weechat_commands = weechat_config_string (
+        relay_config_weechat_commands);
+    if (ptr_weechat_commands && ptr_weechat_commands[0])
+    {
+        weechat_hashtable_set (
+            options,
+            "commands",
+            weechat_config_string (relay_config_weechat_commands));
+    }
+    /*
+     * delay the execution of command after we go back in the WeeChat
+     * main loop (some commands like /upgrade executed now can cause
+     * a crash)
+     */
+    weechat_hashtable_set (options, "delay", "1");
+
+    /* execute the command, with the delay */
+    weechat_command_options (ptr_buffer, pos, options);
+
+    weechat_hashtable_free (options);
+
     return WEECHAT_RC_OK;
 }
 
@@ -1016,7 +1030,13 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(sync)
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(0);
 
-    buffers = weechat_string_split ((argc > 0) ? argv[0] : "*", ",", 0, 0,
+    buffers = weechat_string_split ((argc > 0) ? argv[0] : "*",
+                                    ",",
+                                    NULL,
+                                    WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                    | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                    | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                    0,
                                     &num_buffers);
     if (buffers)
     {
@@ -1024,7 +1044,11 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(sync)
         if (argc > 1)
         {
             add_flags = 0;
-            flags = weechat_string_split (argv[1], ",", 0, 0, &num_flags);
+            flags = weechat_string_split (argv[1], ",", NULL,
+                                          WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                          0, &num_flags);
             if (flags)
             {
                 for (i = 0; i < num_flags; i++)
@@ -1095,7 +1119,13 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(desync)
 
     RELAY_WEECHAT_PROTOCOL_MIN_ARGS(0);
 
-    buffers = weechat_string_split ((argc > 0) ? argv[0] : "*", ",", 0, 0,
+    buffers = weechat_string_split ((argc > 0) ? argv[0] : "*",
+                                    ",",
+                                    NULL,
+                                    WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                    | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                    | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                    0,
                                     &num_buffers);
     if (buffers)
     {
@@ -1103,7 +1133,11 @@ RELAY_WEECHAT_PROTOCOL_CALLBACK(desync)
         if (argc > 1)
         {
             sub_flags = 0;
-            flags = weechat_string_split (argv[1], ",", 0, 0, &num_flags);
+            flags = weechat_string_split (argv[1], ",", NULL,
+                                          WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                          | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                          | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                          0, &num_flags);
             if (flags)
             {
                 for (i = 0; i < num_flags; i++)
@@ -1374,8 +1408,16 @@ relay_weechat_protocol_recv (struct t_relay_client *client, const char *data)
         {
             pos++;
         }
-        argv = weechat_string_split (pos, " ", 0, 0, &argc);
-        argv_eol = weechat_string_split (pos, " ", 2, 0, NULL);
+        argv = weechat_string_split (pos, " ", NULL,
+                                     WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                     | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                     | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                     0, &argc);
+        argv_eol = weechat_string_split (pos, " ", NULL,
+                                         WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
+                                         | WEECHAT_STRING_SPLIT_KEEP_EOL,
+                                         0, NULL);
     }
 
     for (i = 0; protocol_cb[i].name; i++)
@@ -1383,10 +1425,11 @@ relay_weechat_protocol_recv (struct t_relay_client *client, const char *data)
         if (strcmp (protocol_cb[i].name, command) == 0)
         {
             if ((strcmp (protocol_cb[i].name, "init") != 0)
-                && (!RELAY_WEECHAT_DATA(client, password_ok)))
+                && (!RELAY_WEECHAT_DATA(client, password_ok)
+                    || !RELAY_WEECHAT_DATA(client, totp_ok)))
             {
                 /*
-                 * command is not "init" and password is not set?
+                 * command is not "init" and password or totp are not set?
                  * then close connection!
                  */
                 relay_client_set_status (client,
