@@ -20,10 +20,10 @@
 #ifndef WEECHAT_PLUGIN_RELAY_WEECHAT_PROTOCOL_H
 #define WEECHAT_PLUGIN_RELAY_WEECHAT_PROTOCOL_H
 
-#define RELAY_WEECHAT_PROTOCOL_SYNC_BUFFER   1
-#define RELAY_WEECHAT_PROTOCOL_SYNC_NICKLIST 2
-#define RELAY_WEECHAT_PROTOCOL_SYNC_BUFFERS  4
-#define RELAY_WEECHAT_PROTOCOL_SYNC_UPGRADE  8
+#define RELAY_WEECHAT_PROTOCOL_SYNC_BUFFER   (1 << 0)
+#define RELAY_WEECHAT_PROTOCOL_SYNC_NICKLIST (1 << 1)
+#define RELAY_WEECHAT_PROTOCOL_SYNC_BUFFERS  (1 << 2)
+#define RELAY_WEECHAT_PROTOCOL_SYNC_UPGRADE  (1 << 3)
 
 #define RELAY_WEECHAT_PROTOCOL_SYNC_ALL         \
     (RELAY_WEECHAT_PROTOCOL_SYNC_BUFFER |       \
