@@ -1,7 +1,7 @@
 /*
  * script-command.c - script command
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -346,15 +346,15 @@ script_command_init ()
            "  alt+v  view script\n"
            "\n"
            "Input allowed on script buffer:\n"
-           "  i/r/l/L/u/h  action on script (same as keys above)\n"
-           "  q            close buffer\n"
-           "  $            refresh buffer\n"
-           "  s:x,y        sort buffer using keys x and y (see /help "
+           "  i/r/l/L/u/A/h/v  action on script (same as keys above)\n"
+           "  q                close buffer\n"
+           "  $                refresh buffer\n"
+           "  s:x,y            sort buffer using keys x and y (see /help "
            "script.look.sort)\n"
-           "  s:           reset sort (use default sort)\n"
-           "  word(s)      filter scripts: search word(s) in scripts "
+           "  s:               reset sort (use default sort)\n"
+           "  word(s)          filter scripts: search word(s) in scripts "
            "(description, tags, ...)\n"
-           "  *            remove filter\n"
+           "  *                remove filter\n"
            "\n"
            "Mouse actions on script buffer:\n"
            "  wheel         scroll list\n"
