@@ -166,8 +166,7 @@ script_repo_search_by_name_ext (const char *name_with_extension)
 char *
 script_repo_get_filename_loaded (struct t_script_repo *script)
 {
-    const char *weechat_home;
-    char *filename, resolved_path[PATH_MAX];
+    char *weechat_home, *filename, resolved_path[PATH_MAX];
     int length;
     struct stat st;
 
@@ -175,7 +174,11 @@ script_repo_get_filename_loaded (struct t_script_repo *script)
     length = strlen (weechat_home) + strlen (script->name_with_extension) + 64;
     filename = malloc (length);
     if (!filename)
+    {
+        if (weechat_home)
+            free (weechat_home);
         return NULL;
+    }
 
     snprintf (filename, length, "%s/%s/autoload/%s",
               weechat_home,
@@ -193,6 +196,9 @@ script_repo_get_filename_loaded (struct t_script_repo *script)
         }
     }
 
+    if (weechat_home)
+        free (weechat_home);
+
     if (!filename[0])
     {
         free (filename);
@@ -385,7 +391,7 @@ script_repo_alloc ()
         new_script->requirements = NULL;
         new_script->min_weechat = NULL;
         new_script->max_weechat = NULL;
-        new_script->md5sum = NULL;
+        new_script->sha512sum = NULL;
         new_script->url = NULL;
         new_script->popularity = 0;
         new_script->date_added = 0;
@@ -636,8 +642,8 @@ script_repo_free (struct t_script_repo *script)
         free (script->min_weechat);
     if (script->max_weechat)
         free (script->max_weechat);
-    if (script->md5sum)
-        free (script->md5sum);
+    if (script->sha512sum)
+        free (script->sha512sum);
     if (script->url)
         free (script->url);
     if (script->version_loaded)
@@ -740,23 +746,23 @@ script_repo_script_is_held (struct t_script_repo *script)
 }
 
 /*
- * Computes MD5 checksum for the content of a file.
+ * Computes SHA-512 checksum for the content of a file.
  *
  * Note: result must be freed after use.
  */
 
 char *
-script_repo_md5sum_file (const char *filename)
+script_repo_sha512sum_file (const char *filename)
 {
     struct stat st;
     FILE *file;
-    char md5sum[512];
+    char sha512sum[512];
     const char *hexa = "0123456789abcdef";
     unsigned char *data, *result;
     gcry_md_hd_t hd;
     int mdlen, i;
 
-    md5sum[0] = '\0';
+    sha512sum[0] = '\0';
 
     if (stat (filename, &st) == -1)
         return NULL;
@@ -774,21 +780,21 @@ script_repo_md5sum_file (const char *filename)
     }
     fclose (file);
 
-    gcry_md_open (&hd, GCRY_MD_MD5, 0);
-    mdlen = gcry_md_get_algo_dlen (GCRY_MD_MD5);
+    gcry_md_open (&hd, GCRY_MD_SHA512, 0);
+    mdlen = gcry_md_get_algo_dlen (GCRY_MD_SHA512);
     gcry_md_write (hd, data, st.st_size);
-    result = gcry_md_read (hd, GCRY_MD_MD5);
+    result = gcry_md_read (hd, GCRY_MD_SHA512);
     for (i = 0; i < mdlen; i++)
     {
-        md5sum[i * 2] = hexa[(result[i] & 0xFF) / 16];
-        md5sum[(i * 2) + 1] = hexa[(result[i] & 0xFF) % 16];
+        sha512sum[i * 2] = hexa[(result[i] & 0xFF) / 16];
+        sha512sum[(i * 2) + 1] = hexa[(result[i] & 0xFF) % 16];
     }
-    md5sum[((mdlen - 1) * 2) + 2] = '\0';
+    sha512sum[((mdlen - 1) * 2) + 2] = '\0';
     gcry_md_close (hd);
 
     free (data);
 
-    return strdup (md5sum);
+    return strdup (sha512sum);
 }
 
 /*
@@ -801,14 +807,14 @@ script_repo_md5sum_file (const char *filename)
 void
 script_repo_update_status (struct t_script_repo *script)
 {
-    const char *weechat_home, *version;
-    char *filename, *md5sum;
+    const char *version;
+    char *weechat_home, *filename, *sha512sum;
     struct stat st;
     int length;
     struct t_script_repo *ptr_script;
 
     script->status = 0;
-    md5sum = NULL;
+    sha512sum = NULL;
 
     /* check if script is installed (file found on disk) */
     weechat_home = weechat_info_get ("weechat_dir", NULL);
@@ -824,7 +830,7 @@ script_repo_update_status (struct t_script_repo *script)
         {
             script->status |= SCRIPT_STATUS_INSTALLED;
             script->status |= SCRIPT_STATUS_AUTOLOADED;
-            md5sum = script_repo_md5sum_file (filename);
+            sha512sum = script_repo_sha512sum_file (filename);
         }
         else
         {
@@ -835,12 +841,15 @@ script_repo_update_status (struct t_script_repo *script)
             if (stat (filename, &st) == 0)
             {
                 script->status |= SCRIPT_STATUS_INSTALLED;
-                md5sum = script_repo_md5sum_file (filename);
+                sha512sum = script_repo_sha512sum_file (filename);
             }
         }
         free (filename);
     }
 
+    if (weechat_home)
+        free (weechat_home);
+
     /* check if script is held */
     if (script_repo_script_is_held (script))
         script->status |= SCRIPT_STATUS_HELD;
@@ -864,8 +873,11 @@ script_repo_update_status (struct t_script_repo *script)
     }
 
     /* check if script has new version (script is obsolete) */
-    if (md5sum && script->md5sum && (strcmp (script->md5sum, md5sum) != 0))
+    if (sha512sum && script->sha512sum
+        && (strcmp (script->sha512sum, sha512sum) != 0))
+    {
         script->status |= SCRIPT_STATUS_NEW_VERSION;
+    }
 
     /* recompute max length for version loaded (for display) */
     if (script_repo_max_length_field)
@@ -880,8 +892,8 @@ script_repo_update_status (struct t_script_repo *script)
         }
     }
 
-    if (md5sum)
-        free (md5sum);
+    if (sha512sum)
+        free (sha512sum);
 }
 
 /*
@@ -931,8 +943,18 @@ script_repo_match_filter (struct t_script_repo *script)
     if (!script_repo_filter || strcmp (script_repo_filter, "*") == 0)
         return 1;
 
-    words = weechat_string_split (script_repo_filter, " ", 0, 0, &num_words);
-    tags = weechat_string_split ((script->tags) ? script->tags : "", ",", 0, 0,
+    words = weechat_string_split (script_repo_filter, " ", NULL,
+                                  WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                  | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                  | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                  0, &num_words);
+    tags = weechat_string_split ((script->tags) ? script->tags : "",
+                                 ",",
+                                 NULL,
+                                 WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                 | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                 | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                 0,
                                  &num_tags);
     if (words)
     {
@@ -1130,8 +1152,8 @@ script_repo_file_read (int quiet)
 {
     char *filename, *ptr_line, line[4096], *pos, *pos2, *pos3;
     char *name, *value1, *value2, *value3, *value, *error;
-    char *locale, *locale_language;
-    const char *version, *ptr_locale, *ptr_desc;
+    char *info_locale, *locale, *locale_language, *version;
+    const char *ptr_desc;
     gzFile file;
     struct t_script_repo *script;
     int version_number, version_ok, script_ok, length;
@@ -1156,6 +1178,8 @@ script_repo_file_read (int quiet)
 
     version = weechat_info_get ("version", NULL);
     version_number = weechat_util_version_number (version);
+    if (version)
+        free (version);
 
     filename = script_config_get_xml_filename ();
     if (!filename)
@@ -1185,14 +1209,15 @@ script_repo_file_read (int quiet)
      */
     locale = NULL;
     locale_language = NULL;
-    ptr_locale = weechat_info_get ("locale", NULL);
-    if (ptr_locale)
+    info_locale = weechat_info_get ("locale", NULL);
+    if (info_locale)
     {
-        pos = strchr (ptr_locale, '.');
+        pos = strchr (info_locale, '.');
         if (pos)
-            locale = weechat_strndup (ptr_locale, pos - ptr_locale);
+            locale = weechat_strndup (info_locale, pos - info_locale);
         else
-            locale = strdup (ptr_locale);
+            locale = strdup (info_locale);
+        free (info_locale);
     }
     if (locale)
     {
@@ -1335,8 +1360,8 @@ script_repo_file_read (int quiet)
                                     script->min_weechat = strdup (value);
                                 else if (strcmp (name, "max_weechat") == 0)
                                     script->max_weechat = strdup (value);
-                                else if (strcmp (name, "md5sum") == 0)
-                                    script->md5sum = strdup (value);
+                                else if (strcmp (name, "sha512sum") == 0)
+                                    script->sha512sum = strdup (value);
                                 else if (strcmp (name, "url") == 0)
                                     script->url = strdup (value);
                                 else if (strcmp (name, "popularity") == 0)
@@ -1396,10 +1421,13 @@ script_repo_file_read (int quiet)
 
     if (scripts_repo && !quiet)
     {
+        version = weechat_info_get ("version", NULL);
         weechat_printf (NULL,
                         _("%s: %d scripts for WeeChat %s"),
                         SCRIPT_PLUGIN_NAME, script_repo_count,
-                        weechat_info_get ("version", NULL));
+                        version);
+        if (version)
+            free (version);
     }
 
     if (!scripts_repo)
@@ -1546,7 +1574,7 @@ script_repo_hdata_script_cb (const void *pointer, void *data,
         WEECHAT_HDATA_VAR(struct t_script_repo, requirements, STRING, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_script_repo, min_weechat, STRING, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_script_repo, max_weechat, STRING, 0, NULL, NULL);
-        WEECHAT_HDATA_VAR(struct t_script_repo, md5sum, STRING, 0, NULL, NULL);
+        WEECHAT_HDATA_VAR(struct t_script_repo, sha512sum, STRING, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_script_repo, url, STRING, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_script_repo, popularity, INTEGER, 0, NULL, NULL);
         WEECHAT_HDATA_VAR(struct t_script_repo, date_added, TIME, 0, NULL, NULL);
@@ -1608,7 +1636,7 @@ script_repo_add_to_infolist (struct t_infolist *infolist,
         return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "max_weechat", script->max_weechat))
         return 0;
-    if (!weechat_infolist_new_var_string (ptr_item, "md5sum", script->md5sum))
+    if (!weechat_infolist_new_var_string (ptr_item, "sha512sum", script->sha512sum))
         return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "url", script->url))
         return 0;
@@ -1656,7 +1684,7 @@ script_repo_print_log ()
         weechat_log_printf ("  requirements. . . . . : '%s'",  ptr_script->requirements);
         weechat_log_printf ("  min_weechat . . . . . : '%s'",  ptr_script->min_weechat);
         weechat_log_printf ("  max_weechat . . . . . : '%s'",  ptr_script->max_weechat);
-        weechat_log_printf ("  md5sum. . . . . . . . : '%s'",  ptr_script->md5sum);
+        weechat_log_printf ("  sha512sum . . . . . . : '%s'",  ptr_script->sha512sum);
         weechat_log_printf ("  url . . . . . . . . . : '%s'",  ptr_script->url);
         weechat_log_printf ("  popularity. . . . . . : %d",    ptr_script->popularity);
         weechat_log_printf ("  date_added. . . . . . : %lld",  (long long)ptr_script->date_added);
