@@ -97,6 +97,7 @@ spell_config_change_commands (const void *pointer, void *data,
         spell_commands_to_check = weechat_string_split (
             value,
             ",",
+            NULL,
             WEECHAT_STRING_SPLIT_STRIP_LEFT
             | WEECHAT_STRING_SPLIT_STRIP_RIGHT
             | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -509,7 +510,7 @@ spell_config_init ()
         N_("comma separated list of commands for which spell checking is "
            "enabled (spell checking is disabled for all other commands)"),
         NULL, 0, 0,
-        "ame,amsg,away,command,cycle,kick,kickban,me,msg,notice,part,query,"
+        "away,command,cycle,kick,kickban,me,msg,notice,part,query,"
         "quit,topic", NULL, 0,
         NULL, NULL, NULL,
         &spell_config_change_commands, NULL, NULL,
