@@ -57,7 +57,6 @@ int tcl_eval_mode = 0;
 int tcl_eval_send_input = 0;
 int tcl_eval_exec_commands = 0;
 struct t_gui_buffer *tcl_eval_buffer = NULL;
-char *tcl_eval_output = NULL;
 
 struct t_plugin_script *tcl_scripts = NULL;
 struct t_plugin_script *last_tcl_script = NULL;
@@ -760,12 +759,12 @@ weechat_tcl_hdata_cb (const void *pointer, void *data,
  * Returns tcl info "tcl_eval".
  */
 
-const char *
+char *
 weechat_tcl_info_eval_cb (const void *pointer, void *data,
                           const char *info_name,
                           const char *arguments)
 {
-    static const char *not_implemented = "not yet implemented";
+    const char *not_implemented = "not yet implemented";
 
     /* make C compiler happy */
     (void) pointer;
@@ -773,7 +772,7 @@ weechat_tcl_info_eval_cb (const void *pointer, void *data,
     (void) info_name;
     (void) arguments;
 
-    return not_implemented;
+    return strdup (not_implemented);
 }
 
 /*
@@ -984,8 +983,6 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
     if (tcl_action_autoload_list)
         free (tcl_action_autoload_list);
     /* weechat_string_dyn_free (tcl_buffer_output, 1); */
-    if (tcl_eval_output)
-        free (tcl_eval_output);
 
     return WEECHAT_RC_OK;
 }
