@@ -127,6 +127,14 @@ extern int trigger_callback_config_cb  (const void *pointer, void *data,
 extern struct t_hashtable *trigger_callback_focus_cb (const void *pointer,
                                                       void *data,
                                                       struct t_hashtable *info);
+extern char *trigger_callback_info_cb (const void *pointer,
+                                       void *data,
+                                       const char *info_name,
+                                       const char *arguments);
+extern struct t_hashtable *trigger_callback_info_hashtable_cb (const void *pointer,
+                                                               void *data,
+                                                               const char *info_name,
+                                                               struct t_hashtable *hashtable);
 extern void trigger_callback_init ();
 extern void trigger_callback_end ();
 
