@@ -276,12 +276,14 @@ trigger_hook (struct t_trigger *trigger)
     argv = weechat_string_split (
         weechat_config_string (trigger->options[TRIGGER_OPTION_ARGUMENTS]),
         ";",
+        NULL,
         0,
         0,
         &argc);
     argv_eol = weechat_string_split (
         weechat_config_string (trigger->options[TRIGGER_OPTION_ARGUMENTS]),
         ";",
+        NULL,
         WEECHAT_STRING_SPLIT_KEEP_EOL,
         0,
         NULL);
@@ -1299,7 +1301,9 @@ trigger_debug_dump_cb (const void *pointer, void *data,
 int
 weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 {
-    int i, upgrading;
+    /* make C compiler happy */
+    (void) argc;
+    (void) argv;
 
     weechat_plugin = plugin;
 
@@ -1318,17 +1322,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     /* hook completions */
     trigger_completion_init ();
 
-    /* look at arguments */
-    upgrading = 0;
-    for (i = 0; i < argc; i++)
-    {
-        if (weechat_strcasecmp (argv[i], "--upgrade") == 0)
-        {
-            upgrading = 1;
-        }
-    }
-
-    if (upgrading)
+    if (weechat_trigger_plugin->upgrading)
         trigger_buffer_set_callbacks ();
 
     return WEECHAT_RC_OK;
