@@ -55,6 +55,8 @@ enum t_trigger_hook_type
     TRIGGER_HOOK_TIMER,
     TRIGGER_HOOK_CONFIG,
     TRIGGER_HOOK_FOCUS,
+    TRIGGER_HOOK_INFO,
+    TRIGGER_HOOK_INFO_HASHTABLE,
     /* number of hook types */
     TRIGGER_NUM_HOOK_TYPES,
 };
