@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_PLUGIN_XFER_CONFIG_H
@@ -40,7 +40,8 @@ extern struct t_config_option *xfer_config_network_fast_send;
 extern struct t_config_option *xfer_config_network_own_ip;
 extern struct t_config_option *xfer_config_network_port_range;
 extern struct t_config_option *xfer_config_network_send_ack;
-extern struct t_config_option *xfer_config_network_speed_limit;
+extern struct t_config_option *xfer_config_network_speed_limit_send;
+extern struct t_config_option *xfer_config_network_speed_limit_recv;
 extern struct t_config_option *xfer_config_network_timeout;
 
 extern struct t_config_option *xfer_config_file_auto_accept_chats;
