@@ -1,7 +1,7 @@
 /*
  * xfer-file.c - file functions for xfer plugin
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -80,8 +80,7 @@ xfer_file_resume (struct t_xfer *xfer, const char *filename)
 void
 xfer_file_find_filename (struct t_xfer *xfer)
 {
-    const char *dir_separator;
-    char *path, *filename2;
+    char *dir_separator, *path, *filename2;
     int length;
 
     if (!XFER_IS_FILE(xfer->type))
@@ -106,7 +105,11 @@ xfer_file_find_filename (struct t_xfer *xfer)
     dir_separator = weechat_info_get ("dir_separator", "");
     if (dir_separator
         && (xfer->local_filename[strlen (xfer->local_filename) - 1] != dir_separator[0]))
+    {
         strcat (xfer->local_filename, dir_separator);
+    }
+    if (dir_separator)
+        free (dir_separator);
     if (weechat_config_boolean (xfer_config_file_use_nick_in_filename))
     {
         strcat (xfer->local_filename, xfer->remote_nick);
