@@ -1,7 +1,7 @@
 /*
  * tests.cpp - run WeeChat tests
  *
- * Copyright (C) 2014-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2014-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,13 +16,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <iostream>
 #include <stdlib.h>
 #include <unistd.h>
 #include <stdio.h>
+#include <dlfcn.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -52,6 +53,10 @@ extern "C"
 
 #define WEECHAT_TESTS_HOME "./tmp_weechat_test"
 
+/* lib with tests on plugins when autotools is used to compile */
+#define WEECHAT_TESTS_PLUGINS_LIB_DEFAULT                       \
+    "./tests/.libs/lib_weechat_unit_tests_plugins.so.0.0.0"
+
 /* import tests from libs */
 /* core */
 IMPORT_TEST_GROUP(Plugins);
@@ -62,12 +67,14 @@ IMPORT_TEST_GROUP(CoreHdata);
 IMPORT_TEST_GROUP(CoreHook);
 IMPORT_TEST_GROUP(CoreInfolist);
 IMPORT_TEST_GROUP(CoreList);
+IMPORT_TEST_GROUP(CoreSecure);
 IMPORT_TEST_GROUP(CoreString);
 IMPORT_TEST_GROUP(CoreUrl);
 IMPORT_TEST_GROUP(CoreUtf8);
 IMPORT_TEST_GROUP(CoreUtil);
 /* GUI */
 IMPORT_TEST_GROUP(GuiLine);
+IMPORT_TEST_GROUP(GuiNick);
 /* scripts */
 IMPORT_TEST_GROUP(Scripts);
 
@@ -107,8 +114,11 @@ test_print_cb (const void *pointer, void *data, struct t_gui_buffer *buffer,
     (void) highlight;
 
     /* keep only messages displayed on core buffer */
-    if (strcmp (gui_buffer_get_string (buffer, "full_name"), "core.weechat") != 0)
+    if (strcmp (gui_buffer_get_string (buffer, "full_name"),
+                "core.weechat") != 0)
+    {
         return WEECHAT_RC_OK;
+    }
 
     printf ("%s%s%s\n",  /* with color: "\33[34m%s%s%s\33[0m\n" */
             (prefix && prefix[0]) ? prefix : "",
@@ -153,7 +163,7 @@ void
 run_cmd (const char *command)
 {
     printf (">>> Running command: %s\n", command);
-    input_data (ptr_core_buffer, command);
+    input_data (ptr_core_buffer, command, NULL);
 }
 
 /*
@@ -164,7 +174,10 @@ int
 main (int argc, char *argv[])
 {
     int rc, length, weechat_argc;
-    char *weechat_tests_args, *args, **weechat_argv;
+    char *weechat_tests_args, *args, **weechat_argv, *tests_plugins_lib;
+    const char *tests_plugins_lib_default = WEECHAT_TESTS_PLUGINS_LIB_DEFAULT;
+    const char *ptr_path;
+    void *handle;
 
     /* setup environment: English language, no specific timezone */
     setenv ("LC_ALL", LOCALE_TESTS, 1);
@@ -205,7 +218,6 @@ main (int argc, char *argv[])
     printf ("WeeChat arguments: \"%s\"\n", args);
 
     /* init WeeChat */
-    printf ("------------------------------------------------------------\n");
     weechat_init_gettext ();
     weechat_init (weechat_argc, weechat_argv, &test_gui_init);
     if (weechat_argv)
@@ -224,6 +236,19 @@ main (int argc, char *argv[])
         plugin_auto_load (NULL, 0, 1, 0, 0, NULL);
     }
 
+    /* load plugins tests */
+    tests_plugins_lib = getenv ("WEECHAT_TESTS_PLUGINS_LIB");
+    ptr_path = (tests_plugins_lib && tests_plugins_lib[0]) ?
+        tests_plugins_lib : tests_plugins_lib_default;
+    printf ("Loading tests on plugins: \"%s\"\n", ptr_path);
+    handle = dlopen (ptr_path, RTLD_GLOBAL | RTLD_NOW);
+    if (!handle)
+    {
+        fprintf (stderr, "ERROR: unable to load tests on plugins: %s\n",
+                 dlerror ());
+        return 1;
+    }
+
     /* display WeeChat version and directories */
     run_cmd ("/command core version");
     run_cmd ("/debug dirs");
@@ -231,20 +256,13 @@ main (int argc, char *argv[])
 
     /* run all tests */
     printf ("\n");
-    printf (">>>>>>>>>> TESTS >>>>>>>>>>\n");
     rc = CommandLineTestRunner::RunAllTests (argc, argv);
-    printf ("<<<<<<<<<< TESTS <<<<<<<<<<\n");
-    printf ("\n");
 
     /* end WeeChat */
+    gui_chat_mute = GUI_CHAT_MUTE_ALL_BUFFERS;
     weechat_end (&gui_main_end);
-    printf ("------------------------------------------------------------\n");
 
-    /* display status */
-    printf ("\n");
-    printf ("\33[%d;1m*** %s ***\33[0m\n",
-            (rc == 0) ? 32 : 31,  /* 32 = green (OK), 31 = red (error) */
-            (rc == 0) ? "OK" : "ERROR");
+    dlclose (handle);
 
     return rc;
 }
