@@ -468,6 +468,7 @@ TEST(CoreString, Match)
     LONGS_EQUAL(0, string_match ("test", "*es", 0));
     LONGS_EQUAL(0, string_match ("test", "*es", 1));
     LONGS_EQUAL(1, string_match ("test", "*es*", 0));
+    LONGS_EQUAL(1, string_match ("test", "**es**", 0));
     LONGS_EQUAL(1, string_match ("test", "*es*", 1));
     LONGS_EQUAL(1, string_match ("test", "*ES*", 0));
     LONGS_EQUAL(0, string_match ("test", "*ES*", 1));
@@ -491,6 +492,67 @@ TEST(CoreString, Match)
     LONGS_EQUAL(1, string_match ("aabaabaabaa", "aa*", 1));
 }
 
+/*
+ * Tests functions:
+ *   string_match
+ */
+
+TEST(CoreString, MatchList)
+{
+    const char *masks_none[1] = { NULL };
+    const char *masks_one_empty[2] = { "", NULL };
+    const char *masks_one[2] = { "toto", NULL };
+    const char *masks_two[3] = { "toto", "abc", NULL };
+    const char *masks_negative[3] = { "*", "!abc", NULL };
+    const char *masks_negative_star[3] = { "*", "!abc*", NULL };
+
+    LONGS_EQUAL(0, string_match_list (NULL, NULL, 0));
+    LONGS_EQUAL(0, string_match_list (NULL, masks_one, 0));
+
+    LONGS_EQUAL(0, string_match_list ("", NULL, 0));
+    LONGS_EQUAL(0, string_match_list ("", masks_none, 0));
+    LONGS_EQUAL(0, string_match_list ("", masks_one_empty, 0));
+    LONGS_EQUAL(0, string_match_list ("", masks_none, 0));
+    LONGS_EQUAL(0, string_match_list ("", masks_one_empty, 0));
+
+    LONGS_EQUAL(0, string_match_list ("toto", NULL, 0));
+    LONGS_EQUAL(0, string_match_list ("toto", masks_none, 0));
+    LONGS_EQUAL(0, string_match_list ("toto", masks_one_empty, 0));
+    LONGS_EQUAL(0, string_match_list ("toto", masks_none, 0));
+    LONGS_EQUAL(0, string_match_list ("toto", masks_one_empty, 0));
+
+    LONGS_EQUAL(0, string_match_list ("test", masks_one, 0));
+    LONGS_EQUAL(0, string_match_list ("to", masks_one, 0));
+    LONGS_EQUAL(1, string_match_list ("toto", masks_one, 0));
+    LONGS_EQUAL(1, string_match_list ("TOTO", masks_one, 0));
+    LONGS_EQUAL(0, string_match_list ("TOTO", masks_one, 1));
+
+    LONGS_EQUAL(0, string_match_list ("test", masks_two, 0));
+    LONGS_EQUAL(1, string_match_list ("toto", masks_two, 0));
+    LONGS_EQUAL(1, string_match_list ("abc", masks_two, 0));
+    LONGS_EQUAL(0, string_match_list ("def", masks_two, 0));
+
+    LONGS_EQUAL(1, string_match_list ("test", masks_negative, 0));
+    LONGS_EQUAL(1, string_match_list ("toto", masks_negative, 0));
+    LONGS_EQUAL(0, string_match_list ("abc", masks_negative, 0));
+    LONGS_EQUAL(0, string_match_list ("ABC", masks_negative, 0));
+    LONGS_EQUAL(1, string_match_list ("ABC", masks_negative, 1));
+    LONGS_EQUAL(1, string_match_list ("abcdef", masks_negative, 0));
+    LONGS_EQUAL(1, string_match_list ("ABCDEF", masks_negative, 0));
+    LONGS_EQUAL(1, string_match_list ("ABCDEF", masks_negative, 1));
+    LONGS_EQUAL(1, string_match_list ("def", masks_negative, 0));
+
+    LONGS_EQUAL(1, string_match_list ("test", masks_negative_star, 0));
+    LONGS_EQUAL(1, string_match_list ("toto", masks_negative_star, 0));
+    LONGS_EQUAL(0, string_match_list ("abc", masks_negative_star, 0));
+    LONGS_EQUAL(0, string_match_list ("ABC", masks_negative_star, 0));
+    LONGS_EQUAL(1, string_match_list ("ABC", masks_negative_star, 1));
+    LONGS_EQUAL(0, string_match_list ("abcdef", masks_negative_star, 0));
+    LONGS_EQUAL(0, string_match_list ("ABCDEF", masks_negative_star, 0));
+    LONGS_EQUAL(1, string_match_list ("ABCDEF", masks_negative_star, 1));
+    LONGS_EQUAL(1, string_match_list ("def", masks_negative_star, 0));
+}
+
 /*
  * Tests functions:
  *   string_expand_home
@@ -947,35 +1009,56 @@ TEST(CoreString, ReplaceWithCallback)
 TEST(CoreString, Split)
 {
     char **argv;
-    int argc;
+    int argc, flags;
 
-    POINTERS_EQUAL(NULL, string_split (NULL, NULL, 0, 0, NULL));
-    POINTERS_EQUAL(NULL, string_split (NULL, "", 0, 0, NULL));
-    POINTERS_EQUAL(NULL, string_split ("", NULL, 0, 0, NULL));
-    POINTERS_EQUAL(NULL, string_split ("", "", 0, 0, NULL));
+    POINTERS_EQUAL(NULL, string_split (NULL, NULL, NULL, 0, 0, NULL));
+    POINTERS_EQUAL(NULL, string_split (NULL, "", NULL, 0, 0, NULL));
+    POINTERS_EQUAL(NULL, string_split ("", NULL, NULL, 0, 0, NULL));
+    POINTERS_EQUAL(NULL, string_split ("", "", NULL, 0, 0, NULL));
+
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
 
     argc = -1;
-    POINTERS_EQUAL(NULL, string_split (NULL, NULL, 0, 0, &argc));
+    POINTERS_EQUAL(NULL, string_split (NULL, NULL, NULL, flags, 0, &argc));
     LONGS_EQUAL(0, argc);
     argc = -1;
-    POINTERS_EQUAL(NULL, string_split (NULL, "", 0, 0, &argc));
+    POINTERS_EQUAL(NULL, string_split (NULL, "", NULL, flags, 0, &argc));
     LONGS_EQUAL(0, argc);
     argc = -1;
-    POINTERS_EQUAL(NULL, string_split ("", NULL, 0, 0, &argc));
+    POINTERS_EQUAL(NULL, string_split ("", NULL, NULL, flags, 0, &argc));
     LONGS_EQUAL(0, argc);
     argc = -1;
-    POINTERS_EQUAL(NULL, string_split ("", "", 0, 0, &argc));
+    POINTERS_EQUAL(NULL, string_split ("", "", NULL, flags, 0, &argc));
     LONGS_EQUAL(0, argc);
     argc = -1;
-    POINTERS_EQUAL(NULL, string_split ("   ", " ", 0, 0, &argc));
+    POINTERS_EQUAL(NULL, string_split ("   ", " ", NULL, flags, 0, &argc));
     LONGS_EQUAL(0, argc);
 
     /* free split with NULL */
     string_free_split (NULL);
 
     /* standard split */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
     argc = -1;
-    argv = string_split (" abc de  fghi ", " ", 0, 0, &argc);
+    argv = string_split ("abc de  fghi", " ", NULL, flags, 0, &argc);
+    LONGS_EQUAL(3, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("abc", argv[0]);
+    STRCMP_EQUAL("de", argv[1]);
+    STRCMP_EQUAL("fghi", argv[2]);
+    POINTERS_EQUAL(NULL, argv[3]);
+    string_free_split (argv);
+
+    /* standard split */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argc = -1;
+    argv = string_split (" abc de  fghi ", " ", NULL, flags, 0, &argc);
     LONGS_EQUAL(3, argc);
     CHECK(argv);
     STRCMP_EQUAL("abc", argv[0]);
@@ -985,8 +1068,11 @@ TEST(CoreString, Split)
     string_free_split (argv);
 
     /* max 2 items */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
     argc = -1;
-    argv = string_split (" abc de  fghi ", " ", 0, 2, &argc);
+    argv = string_split (" abc de  fghi ", " ", NULL, flags, 2, &argc);
     LONGS_EQUAL(2, argc);
     CHECK(argv);
     STRCMP_EQUAL("abc", argv[0]);
@@ -994,9 +1080,13 @@ TEST(CoreString, Split)
     POINTERS_EQUAL(NULL, argv[2]);
     string_free_split (argv);
 
-    /* keep eol == 1 */
+    /* strip left/right, keep eol for each value */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
+        | WEECHAT_STRING_SPLIT_KEEP_EOL;
     argc = -1;
-    argv = string_split (" abc de  fghi ", " ", 1, 0, &argc);
+    argv = string_split (" abc de  fghi ", " ", NULL, flags, 0, &argc);
     LONGS_EQUAL(3, argc);
     CHECK(argv);
     STRCMP_EQUAL("abc de  fghi", argv[0]);
@@ -1005,9 +1095,13 @@ TEST(CoreString, Split)
     POINTERS_EQUAL(NULL, argv[3]);
     string_free_split (argv);
 
-    /* keep eol == 1 and max 2 items */
+    /* strip left/right, keep eol for each value, max 2 items */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
+        | WEECHAT_STRING_SPLIT_KEEP_EOL;
     argc = -1;
-    argv = string_split (" abc de  fghi ", " ", 1, 2, &argc);
+    argv = string_split (" abc de  fghi ", " ", NULL, flags, 2, &argc);
     LONGS_EQUAL(2, argc);
     CHECK(argv);
     STRCMP_EQUAL("abc de  fghi", argv[0]);
@@ -1015,9 +1109,12 @@ TEST(CoreString, Split)
     POINTERS_EQUAL(NULL, argv[2]);
     string_free_split (argv);
 
-    /* keep eol == 2 */
+    /* strip left, keep eol for each value */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
+        | WEECHAT_STRING_SPLIT_KEEP_EOL;
     argc = -1;
-    argv = string_split (" abc de  fghi ", " ", 2, 0, &argc);
+    argv = string_split (" abc de  fghi ", " ", NULL, flags, 0, &argc);
     LONGS_EQUAL(3, argc);
     CHECK(argv);
     STRCMP_EQUAL("abc de  fghi ", argv[0]);
@@ -1026,15 +1123,168 @@ TEST(CoreString, Split)
     POINTERS_EQUAL(NULL, argv[3]);
     string_free_split (argv);
 
-    /* keep eol == 2 and max 2 items */
+    /* strip left, keep eol for each value, max 2 items */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS
+        | WEECHAT_STRING_SPLIT_KEEP_EOL;
     argc = -1;
-    argv = string_split (" abc de  fghi ", " ", 2, 2, &argc);
+    argv = string_split (" abc de  fghi ", " ", NULL, flags, 2, &argc);
     LONGS_EQUAL(2, argc);
     CHECK(argv);
     STRCMP_EQUAL("abc de  fghi ", argv[0]);
     STRCMP_EQUAL("de  fghi ", argv[1]);
     POINTERS_EQUAL(NULL, argv[2]);
     string_free_split (argv);
+
+    /* standard split with comma separator */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argc = -1;
+    argv = string_split ("abc,de,fghi", ",", NULL, flags, 0, &argc);
+    LONGS_EQUAL(3, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("abc", argv[0]);
+    STRCMP_EQUAL("de", argv[1]);
+    STRCMP_EQUAL("fghi", argv[2]);
+    POINTERS_EQUAL(NULL, argv[3]);
+    string_free_split (argv);
+
+    /*
+     * standard split with comma separator,
+     * strip_items set to empty string (ignored)
+     */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argc = -1;
+    argv = string_split (" abc ,, de ,fghi ,,", ",", "", flags, 0, &argc);
+    LONGS_EQUAL(3, argc);
+    CHECK(argv);
+    STRCMP_EQUAL(" abc ", argv[0]);
+    STRCMP_EQUAL(" de ", argv[1]);
+    STRCMP_EQUAL("fghi ", argv[2]);
+    POINTERS_EQUAL(NULL, argv[3]);
+    string_free_split (argv);
+
+    /*
+     * standard split with comma separator,
+     * strip spaces in items (left/right)
+     */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argc = -1;
+    argv = string_split (" abc ,, de ,fghi ,,", ",", " ", flags, 0, &argc);
+    LONGS_EQUAL(3, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("abc", argv[0]);
+    STRCMP_EQUAL("de", argv[1]);
+    STRCMP_EQUAL("fghi", argv[2]);
+    POINTERS_EQUAL(NULL, argv[3]);
+    string_free_split (argv);
+
+    /*
+     * standard split with comma separator,
+     * strip spaces and parentheses in items (left/right)
+     */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argc = -1;
+    argv = string_split (" abc ,, (de) ,(f(g)hi) ,,", ",", " ()",
+                         flags, 0, &argc);
+    LONGS_EQUAL(3, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("abc", argv[0]);
+    STRCMP_EQUAL("de", argv[1]);
+    STRCMP_EQUAL("f(g)hi", argv[2]);
+    POINTERS_EQUAL(NULL, argv[3]);
+    string_free_split (argv);
+
+    /* standard split with comma separator and empty item (ignore this item) */
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argc = -1;
+    argv = string_split ("abc,,fghi", ",", NULL, flags, 0, &argc);
+    LONGS_EQUAL(2, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("abc", argv[0]);
+    STRCMP_EQUAL("fghi", argv[1]);
+    POINTERS_EQUAL(NULL, argv[2]);
+    string_free_split (argv);
+
+    /* standard split with comma separtor and empty item (keep this item) */
+    flags = 0;
+    argc = -1;
+    argv = string_split ("abc,,fghi", ",", NULL, flags, 0, &argc);
+    LONGS_EQUAL(3, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("abc", argv[0]);
+    STRCMP_EQUAL("", argv[1]);
+    STRCMP_EQUAL("fghi", argv[2]);
+    POINTERS_EQUAL(NULL, argv[3]);
+    string_free_split (argv);
+
+    /* standard split with comma separtor and empty items (keep them) */
+    flags = 0;
+    argc = -1;
+    argv = string_split (",abc,,fghi,", ",", NULL, flags, 0, &argc);
+    LONGS_EQUAL(5, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("", argv[0]);
+    STRCMP_EQUAL("abc", argv[1]);
+    STRCMP_EQUAL("", argv[2]);
+    STRCMP_EQUAL("fghi", argv[3]);
+    STRCMP_EQUAL("", argv[4]);
+    POINTERS_EQUAL(NULL, argv[5]);
+    string_free_split (argv);
+
+    /*
+     * standard split with comma separtor and empty items (keep them),
+     * max 2 items
+     */
+    flags = 0;
+    argc = -1;
+    argv = string_split (",abc,,fghi,", ",", NULL, flags, 2, &argc);
+    LONGS_EQUAL(2, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("", argv[0]);
+    STRCMP_EQUAL("abc", argv[1]);
+    POINTERS_EQUAL(NULL, argv[2]);
+    string_free_split (argv);
+
+    /*
+     * standard split with comma separtor and empty items (keep them),
+     * max 3 items
+     */
+    flags = 0;
+    argc = -1;
+    argv = string_split (",abc,,fghi,", ",", NULL, flags, 3, &argc);
+    LONGS_EQUAL(3, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("", argv[0]);
+    STRCMP_EQUAL("abc", argv[1]);
+    STRCMP_EQUAL("", argv[2]);
+    POINTERS_EQUAL(NULL, argv[3]);
+    string_free_split (argv);
+
+    /*
+     * standard split with comma separtor and empty items (keep them),
+     * max 4 items
+     */
+    flags = 0;
+    argc = -1;
+    argv = string_split (",abc,,fghi,", ",", NULL, flags, 4, &argc);
+    LONGS_EQUAL(4, argc);
+    CHECK(argv);
+    STRCMP_EQUAL("", argv[0]);
+    STRCMP_EQUAL("abc", argv[1]);
+    STRCMP_EQUAL("", argv[2]);
+    STRCMP_EQUAL("fghi", argv[3]);
+    POINTERS_EQUAL(NULL, argv[4]);
+    string_free_split (argv);
 }
 
 /*
@@ -1046,14 +1296,25 @@ TEST(CoreString, Split)
 TEST(CoreString, SplitShared)
 {
     char **argv;
-    int argc;
+    int argc, flags;
 
-    POINTERS_EQUAL(NULL, string_split_shared (NULL, NULL, 0, 0, NULL));
-    POINTERS_EQUAL(NULL, string_split_shared (NULL, "", 0, 0, NULL));
-    POINTERS_EQUAL(NULL, string_split_shared ("", NULL, 0, 0, NULL));
-    POINTERS_EQUAL(NULL, string_split_shared ("", "", 0, 0, NULL));
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
 
-    argv = string_split_shared (" abc de  abc ", " ", 0, 0, &argc);
+    POINTERS_EQUAL(NULL, string_split_shared (NULL, NULL, NULL,
+                                              flags, 0, NULL));
+    POINTERS_EQUAL(NULL, string_split_shared (NULL, "", NULL,
+                                              flags, 0, NULL));
+    POINTERS_EQUAL(NULL, string_split_shared ("", NULL, NULL,
+                                              flags, 0, NULL));
+    POINTERS_EQUAL(NULL, string_split_shared ("", "", NULL,
+                                              flags, 0, NULL));
+
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argv = string_split_shared (" abc de  abc ", " ", NULL, flags, 0, &argc);
     LONGS_EQUAL(3, argc);
     CHECK(argv);
     STRCMP_EQUAL("abc", argv[0]);
@@ -1228,12 +1489,15 @@ TEST(CoreString, SplitTags)
 TEST(CoreString, SplitBuildWithSplitString)
 {
     char **argv, *str;
-    int argc;
+    int argc, flags;
 
     str = string_build_with_split_string (NULL, NULL);
     POINTERS_EQUAL(NULL, str);
 
-    argv = string_split (" abc de  fghi ", " ", 0, 0, &argc);
+    flags = WEECHAT_STRING_SPLIT_STRIP_LEFT
+        | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+        | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS;
+    argv = string_split (" abc de  fghi ", " ", NULL, flags, 0, &argc);
 
     str = string_build_with_split_string ((const char **)argv, NULL);
     STRCMP_EQUAL("abcdefghi", str);
@@ -1631,7 +1895,10 @@ TEST(CoreString, Shared)
     const char *str1, *str2, *str3;
     int count;
 
-    count = string_hashtable_shared->items_count;
+    count = (string_hashtable_shared) ?
+        string_hashtable_shared->items_count : 0;
+
+    POINTERS_EQUAL(NULL, string_shared_get (NULL));
 
     str1 = string_shared_get ("this is a test");
     CHECK(str1);
